@@ -682,6 +682,7 @@ int main(int argc, char *argv[])
 {
     int option;
     unsigned int flags = WATCH_ENABLE;
+    int wait_clicks = 0;  /* cycles to wait before gpsd timeout */
 
     /*@ -observertrans @*/
     switch (gpsd_units()) {
@@ -751,8 +752,8 @@ int main(int argc, char *argv[])
 	    break;
 	    /*@ +observertrans @*/
 	case 'V':
-	    (void)fprintf(stderr, "cgps: %s (revision %s)\n",
-			  VERSION, REVISION);
+	    (void)fprintf(stderr, "%s: %s (revision %s)\n",
+			  argv[0], VERSION, REVISION);
 	    exit(EXIT_SUCCESS);
 	case 'l':
 	    switch (optarg[0]) {
@@ -808,9 +809,13 @@ int main(int argc, char *argv[])
     for (;;) {
 	int c;
 
-	if (!gps_waiting(&gpsdata, 5000000)) {
-	    die(GPS_TIMEOUT);
+        /* wait 1/2 second for gpsd */
+	if (!gps_waiting(&gpsdata, 500000)) {
+            /* 240 tries at .5 Sec a try is a 2 minute timeout */
+	    if ( 240 < wait_clicks++ ) 
+		die(GPS_TIMEOUT);
 	} else {
+	    wait_clicks = 0;
 	    errno = 0;
 	    if (gps_read(&gpsdata) == -1) {
 		fprintf(stderr, "cgps: socket error 4\n");
