@@ -48,10 +48,10 @@ knobs = [
     'nmea0183',
     'nmea2000',
     'nofloats',
+    'ntp',
     'ntpshm',
     'ntrip',
     'oceanserver',
-    'oldstyle',
     'oncore',
     'passthrough',
     'pps',
