@@ -86,7 +86,7 @@ static void print_data(struct gps_context_t *context,
 	ptr += l2;
         for (l1=0;l1<len;l1++) {
             if (((l1 % 20) == 0) && (l1 != 0)) {
-	        gpsd_report(&context->errout, LOG_IO,"%s\n", bu);
+	        gpsd_log(&context->errout, LOG_IO,"%s\n", bu);
 		ptr = 0;
                 l2 = sprintf(&bu[ptr], "                   : ");
 		ptr += l2;
@@ -94,7 +94,7 @@ static void print_data(struct gps_context_t *context,
             l2 = sprintf(&bu[ptr], "%02ux ", (unsigned int)buffer[l1]);
 	    ptr += l2;
         }
-        gpsd_report(&context->errout, LOG_IO,"%s\n", bu);
+        gpsd_log(&context->errout, LOG_IO,"%s\n", bu);
     }
     /*@+bufferoverflowhigh@*/
 #else
@@ -129,21 +129,17 @@ static int decode_ais_header(struct gps_context_t *context,
 	ais->repeat = (unsigned int) ((bu[0] >> 6) & 0x03);
 	ais->mmsi   = (unsigned int)  getleu32(bu, 1);
 	ais->mmsi  &= mask;
-	gpsd_report(&context->errout, LOG_INF,
-		    "NMEA2000 AIS  message type %u, MMSI %09d:\n",
-		    ais->type, ais->mmsi);
-	printf("NMEA2000 AIS  message type %2u, MMSI %09u:\n",
-	       ais->type, ais->mmsi);
+	gpsd_log(&context->errout, LOG_INF,
+		 "NMEA2000 AIS  message type %u, MMSI %09d:\n",
+		 ais->type, ais->mmsi);
 	return(1);
     } else {
         ais->type   =  0;
 	ais->repeat =  0;
 	ais->mmsi   =  0;
-	gpsd_report(&context->errout, LOG_ERROR,
-		    "NMEA2000 AIS  message type %u, too short message.\n",
-		    ais->type);
-	printf("NMEA2000 AIS  message type %u, too short message.\n",
-	       ais->type);
+	gpsd_log(&context->errout, LOG_ERROR,
+		 "NMEA2000 AIS  message type %u, too short message.\n",
+		 ais->type);
     }
     return(0);
 }
@@ -202,8 +198,8 @@ static double ais_direction(unsigned int val, double scale)
 static gps_mask_t hnd_059392(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -214,8 +210,8 @@ static gps_mask_t hnd_059392(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_060928(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -226,8 +222,8 @@ static gps_mask_t hnd_060928(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_126208(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -238,8 +234,8 @@ static gps_mask_t hnd_126208(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_126464(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -250,8 +246,8 @@ static gps_mask_t hnd_126464(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_126996(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -262,8 +258,8 @@ static gps_mask_t hnd_126996(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_127258(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -274,8 +270,8 @@ static gps_mask_t hnd_127258(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_129025(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     /*@-type@*//* splint has a bug here */
     session->newdata.latitude = getles32(bu, 0) * 1e-7;
@@ -292,8 +288,8 @@ static gps_mask_t hnd_129025(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_129026(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     session->driver.nmea2000.sid[0]  =  bu[0];
 
@@ -315,8 +311,8 @@ static gps_mask_t hnd_126992(unsigned char *bu, int len, PGN *pgn, struct gps_de
     //uint8_t        source;
 
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     //sid        = bu[0];
     //source     = bu[1] & 0x0f;
@@ -342,8 +338,8 @@ static gps_mask_t hnd_129539(unsigned char *bu, int len, PGN *pgn, struct gps_de
     unsigned int act_mode;
 
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     mask                             = 0;
     session->driver.nmea2000.sid[1]  = bu[0];
@@ -367,14 +363,14 @@ static gps_mask_t hnd_129539(unsigned char *bu, int len, PGN *pgn, struct gps_de
     /*@+type@*/
     mask                            |= DOP_SET;
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d): sid:%02x hdop:%5.2f vdop:%5.2f tdop:%5.2f\n",
-		pgn->pgn,
-		session->driver.nmea2000.unit,
-		session->driver.nmea2000.sid[1],
-		session->gpsdata.dop.hdop,
-		session->gpsdata.dop.vdop,
-		session->gpsdata.dop.tdop);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d): sid:%02x hdop:%5.2f vdop:%5.2f tdop:%5.2f\n",
+	     pgn->pgn,
+	     session->driver.nmea2000.unit,
+	     session->driver.nmea2000.sid[1],
+	     session->gpsdata.dop.hdop,
+	     session->gpsdata.dop.vdop,
+	     session->gpsdata.dop.tdop);
 
     return mask | get_mode(session);
 }
@@ -388,8 +384,8 @@ static gps_mask_t hnd_129540(unsigned char *bu, int len, PGN *pgn, struct gps_de
     int         l1;
 
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     session->driver.nmea2000.sid[2]           = bu[0];
     session->gpsdata.satellites_visible       = (int)bu[2];
@@ -429,8 +425,8 @@ static gps_mask_t hnd_129029(unsigned char *bu, int len, PGN *pgn, struct gps_de
     gps_mask_t mask;
 
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     mask                             = 0;
     session->driver.nmea2000.sid[3]  = bu[0];
@@ -499,8 +495,8 @@ static gps_mask_t hnd_129038(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         ais->type1.lon       = (int)          scale_int(getles32(bu, 5), (int64_t)(SHIFT32 *.06L));
@@ -532,8 +528,8 @@ static gps_mask_t hnd_129039(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         ais->type18.lon      = (int)          scale_int(getles32(bu, 5), (int64_t)(SHIFT32 *.06L));
@@ -571,8 +567,8 @@ static gps_mask_t hnd_129040(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         uint16_t length, beam, to_bow, to_starboard;
@@ -629,8 +625,8 @@ static gps_mask_t hnd_129794(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         uint16_t  length, beam, to_bow, to_starboard, date;
@@ -726,8 +722,8 @@ static gps_mask_t hnd_129798(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         ais->type9.lon       = (int)          scale_int(getles32(bu, 5), (int64_t)(SHIFT32 *.06L));
@@ -761,8 +757,8 @@ static gps_mask_t hnd_129802(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0x3fffffff) != 0) {
         int                   l;
@@ -789,17 +785,17 @@ static gps_mask_t hnd_129809(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         int                   l;
 	int                   index   = session->driver.aivdm.context[0].type24_queue.index;
 	struct ais_type24a_t *saveptr = &session->driver.aivdm.context[0].type24_queue.ships[index];
 
-	gpsd_report(&session->context->errout, LOG_PROG,
-		    "NMEA2000: AIS message 24A from %09u stashed.\n",
-		    ais->mmsi);
+	gpsd_log(&session->context->errout, LOG_PROG,
+		 "NMEA2000: AIS message 24A from %09u stashed.\n",
+		 ais->mmsi);
 
 	for (l=0;l<AIS_SHIPNAME_MAXLEN;l++) {
 	    ais->type24.shipname[l] = (char) bu[ 5+l];
@@ -832,8 +828,8 @@ static gps_mask_t hnd_129810(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     ais =  &session->gpsdata.ais;
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
     if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
         int l, i;
@@ -883,8 +879,8 @@ static gps_mask_t hnd_129810(unsigned char *bu, int len, PGN *pgn, struct gps_de
 		}
 		ais->type24.shipname[AIS_SHIPNAME_MAXLEN] = (char) 0;
 
-		gpsd_report(&session->context->errout, LOG_PROG,
-			    "NMEA2000: AIS 24B from %09u matches a 24A.\n",
+		gpsd_log(&session->context->errout, LOG_PROG,
+			 "NMEA2000: AIS 24B from %09u matches a 24A.\n",
 			    ais->mmsi);
 		/* prevent false match if a 24B is repeated */
 		session->driver.aivdm.context[0].type24_queue.ships[i].mmsi = 0;
@@ -929,8 +925,8 @@ static gps_mask_t hnd_129810(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_127506(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -941,8 +937,8 @@ static gps_mask_t hnd_127506(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_127508(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -953,8 +949,8 @@ static gps_mask_t hnd_127508(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_127513(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -965,8 +961,8 @@ static gps_mask_t hnd_127513(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_127245(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1015,8 +1011,8 @@ static gps_mask_t hnd_127250(unsigned char *bu, int len, PGN *pgn, struct gps_de
     session->gpsdata.attitude.temp = NAN;
     session->gpsdata.attitude.depth = NAN;
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(ONLINE_SET | ATTITUDE_SET);
 }
 
@@ -1027,8 +1023,8 @@ static gps_mask_t hnd_127250(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_128259(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1061,8 +1057,8 @@ static gps_mask_t hnd_128267(unsigned char *bu, int len, PGN *pgn, struct gps_de
     session->gpsdata.attitude.temp = NAN;
     /*@i@*/session->gpsdata.attitude.depth = getleu32(bu, 1) *.01;
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(ONLINE_SET | ATTITUDE_SET);
 }
 
@@ -1073,8 +1069,8 @@ static gps_mask_t hnd_128267(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_128275(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1085,8 +1081,8 @@ static gps_mask_t hnd_128275(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_129283(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1097,8 +1093,8 @@ static gps_mask_t hnd_129283(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_129284(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1109,8 +1105,8 @@ static gps_mask_t hnd_129284(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_129285(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1121,8 +1117,8 @@ static gps_mask_t hnd_129285(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_130306(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1133,8 +1129,8 @@ static gps_mask_t hnd_130306(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_130310(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1145,8 +1141,8 @@ static gps_mask_t hnd_130310(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_130311(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     print_data(session->context, bu, len, pgn);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
     return(0);
 }
 
@@ -1290,8 +1286,8 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
     session->driver.nmea2000.workpgn = NULL;
     can_net = session->driver.nmea2000.can_net;
     if (can_net > (NMEA2000_NETS-1)) {
-        gpsd_report(&session->context->errout, LOG_ERROR,
-		    "NMEA2000 find_pgn: Invalid can network %d.\n", can_net);
+        gpsd_log(&session->context->errout, LOG_ERROR,
+		 "NMEA2000 find_pgn: Invalid can network %d.\n", can_net);
         return;
     }
 
@@ -1396,8 +1392,8 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 	        if (work->fast == 0) {
 		    size_t l2;
 
-		    gpsd_report(&session->context->errout, LOG_DATA,
-				"pgn %6d:%s \n", work->pgn, work->name);
+		    gpsd_log(&session->context->errout, LOG_DATA,
+			     "pgn %6d:%s \n", work->pgn, work->name);
 		    session->driver.nmea2000.workpgn = (void *) work;
 		    /*@i1@*/session->lexer.outbuflen =  frame->can_dlc & 0x0f;
 		    for (l2=0;l2<session->lexer.outbuflen;l2++) {
@@ -1410,20 +1406,20 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		    /*@i2@*/session->driver.nmea2000.fast_packet_len = frame->data[1];
 		    /*@i2@*/session->driver.nmea2000.idx = frame->data[0];
 #if NMEA2000_FAST_DEBUG
-		    gpsd_report(&session->context->errout, LOG_ERROR,
-				"Set idx    %2x    %2x %2x %6d\n",
-				frame->data[0],
-				session->driver.nmea2000.unit,
-				frame->data[1],
-				source_pgn);
+		    gpsd_log(&session->context->errout, LOG_ERROR,
+			     "Set idx    %2x    %2x %2x %6d\n",
+			     frame->data[0],
+			     session->driver.nmea2000.unit,
+			     frame->data[1],
+			     source_pgn);
 #endif /* of #if NMEA2000_FAST_DEBUG */
 		    session->lexer.inbuflen = 0;
 		    session->driver.nmea2000.idx += 1;
 		    for (l2=2;l2<8;l2++) {
 		        /*@i3@*/session->lexer.inbuffer[session->lexer.inbuflen++] = frame->data[l2];
 		    }
-		    gpsd_report(&session->context->errout, LOG_DATA,
-				"pgn %6d:%s \n", work->pgn, work->name);
+		    gpsd_log(&session->context->errout, LOG_DATA,
+			     "pgn %6d:%s \n", work->pgn, work->name);
 		}
 		/*@i2@*/else if (frame->data[0] == session->driver.nmea2000.idx) {
 		    unsigned int l2;
@@ -1435,9 +1431,9 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		    }
 		    if (session->lexer.inbuflen == session->driver.nmea2000.fast_packet_len) {
 #if NMEA2000_FAST_DEBUG
-		        gpsd_report(&session->context->errout, LOG_ERROR,
-				    "Fast done  %2x %2x %2x %2x %6d\n",
-				    session->driver.nmea2000.idx,
+		        gpsd_log(&session->context->errout, LOG_ERROR,
+				 "Fast done  %2x %2x %2x %2x %6d\n",
+				 session->driver.nmea2000.idx,
 				                                                   /*@i1@*/frame->data[0],
 				                                                   session->driver.nmea2000.unit,
 				                                                   (unsigned int) session->driver.nmea2000.fast_packet_len,
@@ -1453,18 +1449,18 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		        session->driver.nmea2000.idx += 1;
 		    }
 		} else {
-		    gpsd_report(&session->context->errout, LOG_ERROR,
-				"Fast error %2x %2x %2x %2x %6d\n",
-				session->driver.nmea2000.idx,
-				/*@i2@*/frame->data[0],
-				session->driver.nmea2000.unit,
-				(unsigned int) session->driver.nmea2000.fast_packet_len,
+		    gpsd_log(&session->context->errout, LOG_ERROR,
+			     "Fast error %2x %2x %2x %2x %6d\n",
+			     session->driver.nmea2000.idx,
+			     /*@i2@*/frame->data[0],
+			     session->driver.nmea2000.unit,
+			     (unsigned int) session->driver.nmea2000.fast_packet_len,
 				                                               source_pgn);
 		}
 	    } else {
-	        gpsd_report(&session->context->errout, LOG_WARN,
-			    "PGN not found %08d %08x \n",
-			    source_pgn, source_pgn);
+	        gpsd_log(&session->context->errout, LOG_WARN,
+			 "PGN not found %08d %08x \n",
+			 source_pgn, source_pgn);
 	    }
 	} else {
 	    // we got a unknown unit number
@@ -1557,8 +1553,8 @@ int nmea2000_open(struct gps_device_t *session)
 	}
 	if (unit_ptr != NULL) {
 	    if (isdigit(interface_name[l]) == 0) {
-	        gpsd_report(&session->context->errout, LOG_ERROR,
-			    "NMEA2000 open: Invalid character in unit number.\n");
+	        gpsd_log(&session->context->errout, LOG_ERROR,
+			 "NMEA2000 open: Invalid character in unit number.\n");
 	        return -1;
 	    }
 	}
@@ -1567,8 +1563,8 @@ int nmea2000_open(struct gps_device_t *session)
     if (unit_ptr != NULL) {
         unit_number = atoi(unit_ptr);
 	if ((unit_number < 0) || (unit_number > (NMEA2000_UNITS-1))) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"NMEA2000 open: Unit number out of range.\n");
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "NMEA2000 open: Unit number out of range.\n");
 	    return -1;
 	}
 	for (l = 0; l < NMEA2000_NETS; l++) {
@@ -1580,8 +1576,8 @@ int nmea2000_open(struct gps_device_t *session)
 	    }
 	}
 	if (can_net < 0) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"NMEA2000 open: CAN device not open: %s .\n", interface_name);
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "NMEA2000 open: CAN device not open: %s .\n", interface_name);
 	    return -1;
 	}
     } else {
@@ -1589,7 +1585,7 @@ int nmea2000_open(struct gps_device_t *session)
 	    if (strncmp(can_interface_name[l], 
 			interface_name,
 			MIN(sizeof(interface_name), sizeof(can_interface_name[l]))) == 0) {
-	        gpsd_report(&session->context->errout, LOG_ERROR, "NMEA2000 open: CAN device duplicate open: %s .\n", interface_name);
+	        gpsd_log(&session->context->errout, LOG_ERROR, "NMEA2000 open: CAN device duplicate open: %s .\n", interface_name);
 		return -1;
 	    }
 	}
@@ -1600,8 +1596,8 @@ int nmea2000_open(struct gps_device_t *session)
 	    }
 	}
 	if (can_net < 0) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"NMEA2000 open: Too many CAN networks open.\n");
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "NMEA2000 open: Too many CAN networks open.\n");
 	    return -1;
 	}
     }
@@ -1610,15 +1606,15 @@ int nmea2000_open(struct gps_device_t *session)
     sock = socket(PF_CAN, SOCK_RAW, CAN_RAW);
  
     if (BAD_SOCKET(sock)) {
-        gpsd_report(&session->context->errout, LOG_ERROR,
-		    "NMEA2000 open: can not get socket.\n");
+        gpsd_log(&session->context->errout, LOG_ERROR,
+		 "NMEA2000 open: can not get socket.\n");
 	return -1;
     }
 
     status = fcntl(sock, F_SETFL, O_NONBLOCK);
     if (status != 0) {
-        gpsd_report(&session->context->errout, LOG_ERROR,
-		    "NMEA2000 open: can not set socket to O_NONBLOCK.\n");
+        gpsd_log(&session->context->errout, LOG_ERROR,
+		 "NMEA2000 open: can not set socket to O_NONBLOCK.\n");
 	close(sock);
 	return -1;
     }
@@ -1629,8 +1625,8 @@ int nmea2000_open(struct gps_device_t *session)
 					       * with that device's index */
 
     if (status != 0) {
-        gpsd_report(&session->context->errout, LOG_ERROR,
-		    "NMEA2000 open: can not find CAN device.\n");
+        gpsd_log(&session->context->errout, LOG_ERROR,
+		 "NMEA2000 open: can not find CAN device.\n");
 	close(sock);
 	return -1;
     }
@@ -1640,7 +1636,8 @@ int nmea2000_open(struct gps_device_t *session)
     addr.can_ifindex = ifr.ifr_ifindex;
     status = bind(sock, (struct sockaddr*)&addr, sizeof(addr) );
     if (status != 0) {
-        gpsd_report(&session->context->errout, LOG_ERROR, "NMEA2000 open: bind failed.\n");
+        gpsd_log(&session->context->errout, LOG_ERROR,
+		 "NMEA2000 open: bind failed.\n");
 	close(sock);
 	return -1;
     }
@@ -1675,9 +1672,9 @@ int nmea2000_open(struct gps_device_t *session)
 void nmea2000_close(struct gps_device_t *session)
 {
     if (!BAD_SOCKET(session->gpsdata.gps_fd)) {
-	gpsd_report(&session->context->errout, LOG_SPIN,
-		    "close(%d) in nmea2000_close(%s)\n",
-		    session->gpsdata.gps_fd, session->gpsdata.dev.path);
+	gpsd_log(&session->context->errout, LOG_SPIN,
+		 "close(%d) in nmea2000_close(%s)\n",
+		 session->gpsdata.gps_fd, session->gpsdata.dev.path);
 	(void)close(session->gpsdata.gps_fd);
 	INVALIDATE_SOCKET(session->gpsdata.gps_fd);
     }
