@@ -75,8 +75,8 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
 	return 0;
 
     mask = ONLINE_SET;
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"oncore NAVSOL - navigation data\n");
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "oncore NAVSOL - navigation data\n");
 
     flags = (unsigned char)getub(buf, 72);
 
@@ -88,8 +88,8 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
 	session->gpsdata.status = STATUS_FIX;
 	session->newdata.mode = MODE_2D;
     } else {
-	gpsd_report(&session->context->errout, LOG_WARN,
-		    "oncore NAVSOL no fix - flags 0x%02x\n", flags);
+	gpsd_log(&session->context->errout, LOG_WARN,
+		 "oncore NAVSOL no fix - flags 0x%02x\n", flags);
 	session->newdata.mode = MODE_NO_FIX;
 	session->gpsdata.status = STATUS_NO_FIX;
     }
@@ -117,11 +117,11 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
 	session->newdata.time = (timestamp_t)mkgmtime(&unpacked_date) + nsec * 1e-9;
 	/*@ +unrecog */
 	mask |= TIME_SET;
-	gpsd_report(&session->context->errout, LOG_DATA,
-		    "oncore NAVSOL - time: %04d-%02d-%02d %02d:%02d:%02d.%09d\n",
-		    unpacked_date.tm_year + 1900, unpacked_date.tm_mon + 1,
-		    unpacked_date.tm_mday, unpacked_date.tm_hour,
-		    unpacked_date.tm_min, unpacked_date.tm_sec, nsec);
+	gpsd_log(&session->context->errout, LOG_DATA,
+		 "oncore NAVSOL - time: %04d-%02d-%02d %02d:%02d:%02d.%09d\n",
+		 unpacked_date.tm_year + 1900, unpacked_date.tm_mon + 1,
+		 unpacked_date.tm_mday, unpacked_date.tm_hour,
+		 unpacked_date.tm_min, unpacked_date.tm_sec, nsec);
     }
 
     /*@-type@*/
@@ -133,10 +133,10 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
     dop = getbeu16(buf, 35) / 10.0f;
     /*@+type@*/
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"oncore NAVSOL - %lf %lf %.2lfm-%.2lfm | %.2fm/s %.1fdeg dop=%.1f\n",
-		lat, lon, alt, wgs84_separation(lat, lon), speed, track,
-		(float)dop);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "oncore NAVSOL - %lf %lf %.2lfm-%.2lfm | %.2fm/s %.1fdeg dop=%.1f\n",
+	     lat, lon, alt, wgs84_separation(lat, lon), speed, track,
+	     (float)dop);
 
     session->newdata.latitude = lat;
     session->newdata.longitude = lon;
@@ -163,8 +163,8 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
 	sn = (int)getub(buf, off + 2);
 	status = (int)getub(buf, off + 3);
 
-	gpsd_report(&session->context->errout, LOG_DATA,
-		    "%2d %2d %2d %3d %02x\n", i, sv, mode, sn, status);
+	gpsd_log(&session->context->errout, LOG_DATA,
+		 "%2d %2d %2d %3d %02x\n", i, sv, mode, sn, status);
 
 	if (sn) {
 	    session->gpsdata.skyview[st].PRN = (short)sv;
@@ -222,14 +222,14 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
     (void)oncore_control_send(session, (char *)pollBo, sizeof(pollBo));
     (void)oncore_control_send(session, (char *)pollEn, sizeof(pollEn));
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"NAVSOL: time=%.2f lat=%.2f lon=%.2f alt=%.2f speed=%.2f track=%.2f mode=%d status=%d visible=%d used=%d\n",
-		session->newdata.time, session->newdata.latitude,
-		session->newdata.longitude, session->newdata.altitude,
-		session->newdata.speed, session->newdata.track,
-		session->newdata.mode, session->gpsdata.status,
-		session->gpsdata.satellites_used,
-		session->gpsdata.satellites_visible);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "NAVSOL: time=%.2f lat=%.2f lon=%.2f alt=%.2f speed=%.2f track=%.2f mode=%d status=%d visible=%d used=%d\n",
+	     session->newdata.time, session->newdata.latitude,
+	     session->newdata.longitude, session->newdata.altitude,
+	     session->newdata.speed, session->newdata.track,
+	     session->newdata.mode, session->gpsdata.status,
+	     session->gpsdata.satellites_used,
+	     session->gpsdata.satellites_visible);
     return mask;
 }
 
@@ -245,8 +245,8 @@ oncore_msg_utc_offset(struct gps_device_t *session, unsigned char *buf,
     if (data_len != 8)
 	return 0;
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"oncore UTCTIME - leap seconds\n");
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "oncore UTCTIME - leap seconds\n");
     utc_offset = (int)getub(buf, 4);
     if (utc_offset == 0)
 	return 0;		/* that part of almanac not received yet */
@@ -268,7 +268,7 @@ oncore_msg_pps_offset(struct gps_device_t *session, unsigned char *buf,
     if (data_len != 11)
 	return 0;
 
-    gpsd_report(&session->context->errout, LOG_DATA, "oncore PPS offset\n");
+    gpsd_log(&session->context->errout, LOG_DATA, "oncore PPS offset\n");
     pps_offset_ns = (int)getbes32(buf, 4);
 
     session->driver.oncore.pps_offset_ns = pps_offset_ns;
@@ -288,11 +288,11 @@ oncore_msg_svinfo(struct gps_device_t *session, unsigned char *buf,
     if (data_len != 92)
 	return 0;
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"oncore SVINFO - satellite data\n");
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "oncore SVINFO - satellite data\n");
     nchan = (unsigned int)getub(buf, 4);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"oncore SVINFO - %d satellites:\n", nchan);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "oncore SVINFO - %d satellites:\n", nchan);
     /* Then we clamp the value to not read outside the table. */
     if (nchan > 12)
 	nchan = 12;
@@ -305,8 +305,8 @@ oncore_msg_svinfo(struct gps_device_t *session, unsigned char *buf,
 	int el = (int)getub(buf, off + 3);
 	int az = (int)getbeu16(buf, off + 4);
 
-	gpsd_report(&session->context->errout, LOG_DATA,
-		    "%2d %2d %2d %3d\n", i, sv, el, az);
+	gpsd_log(&session->context->errout, LOG_DATA,
+		 "%2d %2d %2d %3d\n", i, sv, el, az);
 
 	/* Store for use when Ea messages come. */
 	session->driver.oncore.PRN[i] = sv;
@@ -320,8 +320,8 @@ oncore_msg_svinfo(struct gps_device_t *session, unsigned char *buf,
 	    }
     }
 
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"SVINFO: mask={SATELLITE}\n");
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "SVINFO: mask={SATELLITE}\n");
     return SATELLITE_SET;
 }
 
@@ -338,8 +338,8 @@ oncore_msg_time_raim(struct gps_device_t *session UNUSED,
 	return 0;
 
     sawtooth_ns = (int)getub(buf, 25);
-    gpsd_report(&session->context->errout, LOG_DATA,
-		"oncore PPS sawtooth: %d\n",sawtooth_ns);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "oncore PPS sawtooth: %d\n",sawtooth_ns);
 
     /* session->driver.oncore.traim_sawtooth_ns = sawtooth_ns; */
 
@@ -373,8 +373,8 @@ gps_mask_t oncore_dispatch(struct gps_device_t * session, unsigned char *buf,
     type = ONCTYPE(buf[2], buf[3]);
 
     /* we may need to dump the raw packet */
-    gpsd_report(&session->context->errout, LOG_RAW,
-		"raw Oncore packet type 0x%04x\n", type);
+    gpsd_log(&session->context->errout, LOG_RAW,
+	     "raw Oncore packet type 0x%04x\n", type);
 
     session->cycle_end_reliable = true;
 
@@ -398,9 +398,9 @@ gps_mask_t oncore_dispatch(struct gps_device_t * session, unsigned char *buf,
 
     default:
 	/* FIX-ME: This gets noisy in a hurry. Change once your driver works */
-	gpsd_report(&session->context->errout, LOG_WARN,
-		    "unknown packet id @@%c%c length %zd\n",
-		    type >> 8, type & 0xff, len);
+	gpsd_log(&session->context->errout, LOG_WARN,
+		 "unknown packet id @@%c%c length %zd\n",
+		 type >> 8, type & 0xff, len);
 	return 0;
     }
 }
@@ -433,8 +433,8 @@ static ssize_t oncore_control_send(struct gps_device_t *session,
     session->msgbuf[msglen + 4] = '\n';
     session->msgbuflen = msglen + 5;
 
-    gpsd_report(&session->context->errout, LOG_PROG,
-		"writing oncore control type %c%c\n", msg[0], msg[1]);
+    gpsd_log(&session->context->errout, LOG_PROG,
+	     "writing oncore control type %c%c\n", msg[0], msg[1]);
     return gpsd_write(session, session->msgbuf, session->msgbuflen);
 }
 
