@@ -48,8 +48,8 @@ const char *gps_maskdump(gps_mask_t set)
         {POLICY_SET,	"POLICY"},
         {LOGMESSAGE_SET,	"LOGMESSAGE"},
         {ERROR_SET,	"ERROR"},
-        {TIMEDRIFT_SET,	"TIMEDRIFT"},
-        {PPSDRIFT_SET,	"PPSDRIFT"},
+        {TOFF_SET,	"TOFF"},
+        {PPS_SET,	"PPS"},
         {RAW_IS,	"RAW"},
         {USED_IS,	"USED"},
         {DRIVER_IS,	"DRIVER"},
