@@ -167,5 +167,5 @@ if __name__ == "__main__":
         d = GPSDictionary()
         d.HTMLDump(sys.stdout)
     except ConfigParser.Error, e:
-        print >>sys.stderr, sys.argv[0]+":", e._Error__message
+        print >>sys.stderr, sys.argv[0]+":", e
         raise SystemExit, 1
