@@ -31,6 +31,7 @@
 #include "gpsdclient.h"
 #include "revision.h"
 #include "strfuncs.h"
+#include "timespec_str.h"
 
 #define BUFLEN		2048
 
@@ -223,8 +224,10 @@ void toff_update(WINDOW *win, int y, int x)
     {
 	/* NOTE: can not use double here due to precision requirements */
 	struct timespec timedelta;
+	int i;
 	(void)wmove(win, y, x);
-	(void)wclrtoeol(win);
+	for (i = 0; i < TIMESPEC_LEN; i++)
+	    (void)waddch(win, ' ');
 	TS_SUB(&timedelta, &time_offset.clock, &time_offset.real);
 	if ( 86400 < (long)labs(timedelta.tv_sec) ) {
 	    /* more than one day off, overflow */
@@ -249,11 +252,13 @@ void pps_update(WINDOW *win, int y, int x)
     /*@-type -noeffect@*/ /* splint is confused about struct timespec */
     struct timedelta_t ppstimes;
 
-    if (pps_thread_lastpps(&session, &ppstimes) > 0) {
+    if (pps_thread_ppsout(&session.pps_thread, &ppstimes) > 0) {
 	/* NOTE: can not use double here due to precision requirements */
 	struct timespec timedelta;
+	int i;
 	(void)wmove(win, y, x);
-	(void)wclrtoeol(win);
+	for (i = 0; i < TIMESPEC_LEN; i++)
+	    (void)waddch(win, ' ');
 	TS_SUB( &timedelta, &ppstimes.clock, &ppstimes.real);
         if ( 86400 < (long)labs(timedelta.tv_sec) ) {
 	    /* more than one day off, overflow */
@@ -790,9 +795,9 @@ static void gpsmon_hook(struct gps_device_t *device, gps_mask_t changed UNUSED)
 			"------------------- PPS offset: %.20s ------\n ",
 			timedelta_str);
 	    /* coverity[missing_lock] */
-	    session.ppslast = noclobber.pps;
+	    session.pps_thread.ppsout_last = noclobber.pps;
 	    /* coverity[missing_lock] */
-	    session.ppscount++;
+	    session.pps_thread.ppsout_count++;
 	}
     }
     else
@@ -847,8 +852,10 @@ static void gpsmon_hook(struct gps_device_t *device, gps_mask_t changed UNUSED)
      * and it is a new second. */
     if ( 0 != isnan(device->newdata.time)) {
 	// "NTP: bad new time
-    } else if (device->newdata.time == device->last_fixtime.real) {
+#if defined(PPS_ENABLE) && !defined(S_SPLINT_S)
+    } else if (device->newdata.time <= device->pps_thread.fixin.real.tv_sec) {
 	// "NTP: Not a new time
+#endif /* PPS_ENABLE */
     } else 
 	ntp_latch(device, &time_offset);
 #endif /* NTP_ENABLE */
@@ -1131,7 +1138,7 @@ static bool do_command(const char *line)
 /*@+globstate +usedef +compdef@*/
 
 #ifdef PPS_ENABLE
-static /*@observer@*/ char *pps_report(struct gps_device_t *session UNUSED,
+static /*@observer@*/ char *pps_report(volatile struct pps_thread_t *pps_thread UNUSED,
 			struct timedelta_t *td UNUSED) {
     packet_log(PPSBAR);
     return "gpsmon";
@@ -1228,7 +1235,7 @@ int main(int argc, char **argv)
 	    }
 	    exit(EXIT_SUCCESS);
 	case 'V':
-	    (void)printf("gpsmon: %s (revision %s)\n", VERSION, REVISION);
+	    (void)printf("%s: %s (revision %s)\n", argv[0], VERSION, REVISION);
 	    exit(EXIT_SUCCESS);
 	case 'l':		/* enable logging at startup */
 	    logfile = fopen(optarg, "w");
@@ -1311,13 +1318,10 @@ int main(int argc, char **argv)
 
     if (serial) {
 #ifdef PPS_ENABLE
-	/* init the pps mutex */
-	pps_early_init( &context);
-
 	/* this guard suppresses a warning on Bluetooth devices */
 	if (session.sourcetype == source_rs232 || session.sourcetype == source_usb) {
-	    session.thread_report_hook = pps_report;
-	    pps_thread_activate(&session);
+	    session.pps_thread.report_hook = pps_report;
+	    pps_thread_activate(&session.pps_thread);
 	}
 #endif /* PPS_ENABLE */
     }
@@ -1448,7 +1452,7 @@ int main(int argc, char **argv)
 #ifdef PPS_ENABLE
     /* Shut down PPS monitoring. */
     if (serial)
-       (void)pps_thread_deactivate(&session);
+       (void)pps_thread_deactivate(&session.pps_thread);
 #endif /* PPS_ENABLE*/
 
     gpsd_close(&session);
