@@ -299,15 +299,9 @@ void gps_merge_fix( /*@ out @*/ struct gps_fix_t *to,
  * near microSec.  Do not use near PPS which is nanoSec precise */
 timestamp_t timestamp(void)
 {
-#ifdef HAVE_CLOCK_GETTIME
      struct timespec ts;
      /*@i2@*/(void)clock_gettime(CLOCK_REALTIME, &ts);
      /*@i3@*/return (timestamp_t)(ts.tv_sec + ts.tv_nsec * 1e-9);
-#else
-    struct timeval tv;
-    (void)gettimeofday(&tv, NULL);
-    return (timestamp_t)(tv.tv_sec + tv.tv_usec * 1e-6);
-#endif
 }
 
 time_t mkgmtime(register struct tm * t)
@@ -485,32 +479,4 @@ double earth_distance(double lat1, double lon1, double lat2, double lon2)
 	return earth_distance_and_bearings(lat1, lon1, lat2, lon2, NULL, NULL);
 }
 
-/* Convert a normailized timespec to a nice string 
- * put in it *buf, buf should be at least 22 bytes
- *
- * the returned buffer will look like, shortest case:
- *    sign character ' ' or '-'
- *    one digit of seconds
- *    decmal point '.'
- *    9 digits of nanoSec
- *
- * So 12 chars, like this: "-0.123456789"
- *
- * Absolute worst case is 10 digits of seconds.  
- * So 21 digits like this: "-2147483647.123456789"
- *
-*/
-void timespec_str(const struct timespec *ts, /*@out@*/char *buf, int buf_size)
-{
-    char sign = ' ';
-
-    /*@-type@*//* splint is confused about timespec*/
-    if ( (0 > ts->tv_nsec ) || ( 0 > ts->tv_sec ) ) {
-	sign = '-';
-    }
-    (void) snprintf( buf, buf_size, "%c%ld.%09ld",
-			  sign,
-			  (long)labs(ts->tv_sec),
-			  (long)labs(ts->tv_nsec));
-    /*@+type@*/
-}
+/* end */
