@@ -67,13 +67,14 @@ PERMISSIONS
 #include <stdlib.h>
 #include <stdbool.h>
 #include <stdarg.h>
+#include <time.h>               /* for time_t */
 #include <ctype.h>
 
 #include "gpsd_config.h"	/* for strlcpy() prototype */
 #ifdef SOCKET_EXPORT_ENABLE
 #include "json.h"
 
-#include "gps.h"		/* for safe_atof() & timestamp_t prototype */
+#include "gps.h"		/* for safe_atof() prototype */
 #include "strfuncs.h"
 
 #define JSON_MINIMAL	/* GPSD only uses a subset of the features */
