@@ -97,25 +97,28 @@ void gpsd_release_reporting_lock(void)
 #endif /* PPS_ENABLE */
 
 #ifndef SQUELCH_ENABLE
-static void visibilize(/*@out@*/char *buf2, size_t len, const char *buf)
+static void visibilize(/*@out@*/char *outbuf, size_t outlen,
+		       const char *inbuf, size_t inlen)
 {
     const char *sp;
 
-    buf2[0] = '\0';
-    for (sp = buf; *sp != '\0' && strlen(buf2)+4 < len; sp++)
+    outbuf[0] = '\0';
+    for (sp = inbuf; sp < inbuf + inlen && strlen(outbuf)+6 < outlen; sp++)
 	if (isprint((unsigned char) *sp) || (sp[0] == '\n' && sp[1] == '\0')
 	  || (sp[0] == '\r' && sp[2] == '\0'))
-	    (void)snprintf(buf2 + strlen(buf2), 2, "%c", *sp);
+	    (void)snprintf(outbuf + strlen(outbuf), 2, "%c", *sp);
 	else
-	    (void)snprintf(buf2 + strlen(buf2), 6, "\\x%02x",
+	    (void)snprintf(outbuf + strlen(outbuf), 6, "\\x%02x",
 			   0x00ff & (unsigned)*sp);
 }
 #endif /* !SQUELCH_ENABLE */
 
-void gpsd_report(const struct gpsd_errout_t *errout, 
-		 const int errlevel,
-		 const char *fmt, ...)
-/* assemble msg in printf(3) style, use errout hook or syslog for delivery */
+
+void gpsd_vlog(const struct gpsd_errout_t *errout, 
+			 const int errlevel,
+			 char *outbuf, size_t outlen,
+			 const char *fmt, va_list ap)
+/* assemble msg in vprintf(3) style, use errout hook or syslog for delivery */
 {
 #ifdef SQUELCH_ENABLE
     (void)errout;
@@ -123,9 +126,8 @@ void gpsd_report(const struct gpsd_errout_t *errout,
     (void)fmt;
 #else
     if (errout->debug >= errlevel) {
-	char buf[BUFSIZ], buf2[BUFSIZ];
+	char buf[BUFSIZ];
 	char *err_str;
-	va_list ap;
 
 #if defined(PPS_ENABLE)
 	gpsd_acquire_reporting_lock();
@@ -169,18 +171,16 @@ void gpsd_report(const struct gpsd_errout_t *errout,
 	(void)strlcpy(buf, errout->label, sizeof(buf));
 	(void)strlcat(buf, ":", sizeof(buf));
 	(void)strlcat(buf, err_str, sizeof(buf));
-	va_start(ap, fmt);
 	str_vappendf(buf, sizeof(buf), fmt, ap);
-	va_end(ap);
 
-	visibilize(buf2, sizeof(buf2), buf);
+	visibilize(outbuf, outlen, buf, strlen(buf));
 
 	if (getpid() == getsid(getpid()))
-	    syslog((errlevel == 0) ? LOG_ERR : LOG_NOTICE, "%s", buf2);
+	    syslog((errlevel == 0) ? LOG_ERR : LOG_NOTICE, "%s", outbuf);
 	else if (errout->report != NULL)
-	    errout->report(buf2);
+	    errout->report(outbuf);
 	else
-	    (void)fputs(buf2, stderr);
+	    (void)fputs(outbuf, stderr);
 #if defined(PPS_ENABLE)
 	gpsd_release_reporting_lock();
 #endif /* PPS_ENABLE */
@@ -188,6 +188,20 @@ void gpsd_report(const struct gpsd_errout_t *errout,
 #endif /* !SQUELCH_ENABLE */
 }
 
+void gpsd_log(const struct gpsd_errout_t *errout, 
+		 const int errlevel,
+		 const char *fmt, ...)
+/* assemble msg in printf(3) style, use errout hook or syslog for delivery */
+{
+    char buf[BUFSIZ];
+    va_list ap;
+
+    buf[0] = '\0';
+    va_start(ap, fmt);
+    gpsd_vlog(errout, errlevel, buf, sizeof(buf), fmt, ap);
+    va_end(ap);
+}
+
 const char *gpsd_prettydump(struct gps_device_t *session)
 /* dump the current packet in a form optimised for eyeballs */
 {
@@ -202,9 +216,9 @@ static void gpsd_run_device_hook(struct gpsd_errout_t *errout,
 {
     struct stat statbuf;
     if (stat(DEVICEHOOKPATH, &statbuf) == -1)
-	gpsd_report(errout, LOG_PROG,
-		    "no %s present, skipped running %s hook\n",
-		    DEVICEHOOKPATH, hook);
+	gpsd_log(errout, LOG_PROG,
+		 "no %s present, skipped running %s hook\n",
+		 DEVICEHOOKPATH, hook);
     else {
 	/*
 	 * We make an exception to the no-malloc rule here because
@@ -214,21 +228,21 @@ static void gpsd_run_device_hook(struct gpsd_errout_t *errout,
 	size_t bufsize = strlen(DEVICEHOOKPATH) + 1 + strlen(device_name) + 1 + strlen(hook) + 1;
 	char *buf = malloc(bufsize);
 	if (buf == NULL)
-	    gpsd_report(errout, LOG_ERROR,
-			"error allocating run-hook buffer\n");
+	    gpsd_log(errout, LOG_ERROR,
+		     "error allocating run-hook buffer\n");
 	else
 	{
 	    int status;
 	    (void)snprintf(buf, bufsize, "%s %s %s",
 			   DEVICEHOOKPATH, device_name, hook);
-	    gpsd_report(errout, LOG_INF, "running %s\n", buf);
+	    gpsd_log(errout, LOG_INF, "running %s\n", buf);
 	    status = system(buf);
 	    if (status == -1)
-		gpsd_report(errout, LOG_ERROR, "error running %s\n", buf);
+		gpsd_log(errout, LOG_ERROR, "error running %s\n", buf);
 	    else
-		gpsd_report(errout, LOG_INF,
-			    "%s returned %d\n", DEVICEHOOKPATH,
-			    WEXITSTATUS(status));
+		gpsd_log(errout, LOG_INF,
+			 "%s returned %d\n", DEVICEHOOKPATH,
+			 WEXITSTATUS(status));
 	    free(buf);
 	}
     }
@@ -245,14 +259,14 @@ int gpsd_switch_driver(struct gps_device_t *session, char *type_name)
     if (first_sync && strcmp(session->device_type->type_name, type_name) == 0)
 	return 0;
 
-    gpsd_report(&session->context->errout, LOG_PROG,
-		"switch_driver(%s) called...\n", type_name);
+    gpsd_log(&session->context->errout, LOG_PROG,
+	     "switch_driver(%s) called...\n", type_name);
     /*@ -compmempass @*/
     for (dp = gpsd_drivers, i = 0; *dp; dp++, i++)
 	if (strcmp((*dp)->type_name, type_name) == 0) {
-	    gpsd_report(&session->context->errout, LOG_PROG,
-			"selecting %s driver...\n",
-			(*dp)->type_name);
+	    gpsd_log(&session->context->errout, LOG_PROG,
+		     "selecting %s driver...\n",
+		     (*dp)->type_name);
 	    gpsd_assert_sync(session);
 	    /*@i@*/ session->device_type = *dp;
 	    session->driver_index = i;
@@ -269,7 +283,8 @@ int gpsd_switch_driver(struct gps_device_t *session, char *type_name)
 #endif /* RECONFIGURE_ENABLE */
 	    return 1;
 	}
-    gpsd_report(&session->context->errout, LOG_ERROR, "invalid GPS type \"%s\".\n", type_name);
+    gpsd_log(&session->context->errout, LOG_ERROR,
+	     "invalid GPS type \"%s\".\n", type_name);
     return 0;
     /*@ +compmempass @*/
     /*@+mustfreeonly@*/
@@ -280,35 +295,12 @@ int gpsd_switch_driver(struct gps_device_t *session, char *type_name)
 void gps_context_init(struct gps_context_t *context, 
 		      /*@observer@*/const char *label)
 {
-    /* *INDENT-OFF* */
-    /*@ -initallelements -nullassign -nullderef -fullinitblock @*/
-    struct gps_context_t nullcontext = {
-	.valid	        = 0,
-	.readonly	= false,
-	.fixcnt	        = 0,
-	.start_time     = 0,
-	.leap_seconds   = 0,
-	.gps_week	= 0,
-	.gps_tow        = 0,
-	.century	= 0,
-	.rollovers      = 0,
+    (void)memset(context, '\0', sizeof(struct gps_context_t));
+    //context.readonly = false;
 #ifdef TIMEHINT_ENABLE
-	.leap_notify    = LEAP_NOWARNING,
+    context->leap_notify    = LEAP_NOWARNING;
 #endif /* TIMEHINT_ENABLE */
-#ifdef NTPSHM_ENABLE
-	.shmTime	= {0},
-#endif /* NTPSHM_ENABLE */
-#ifdef PPS_ENABLE
-	.pps_hook       = NULL,
-#endif /* PPS_ENABLE */
-#ifdef SHM_EXPORT_ENABLE
-	.shmexport      = NULL,
-#endif /* SHM_EXPORT_ENABLE */
-	.serial_write    = gpsd_serial_write,
-    };
-    /*@ +initallelements +nullassign +nullderef +fullinitblock @*/
-    /* *INDENT-ON* */
-    (void)memcpy(context, &nullcontext, sizeof(struct gps_context_t));
+    context->serial_write = gpsd_serial_write;
 
     errout_reset(&context->errout);
     context->errout.label = (char *)label;
@@ -325,18 +317,6 @@ void gpsd_init(struct gps_device_t *session, struct gps_context_t *context,
 	       const char *device)
 /* initialize GPS polling */
 {
-    /* clear some times */
-    session->last_fixtime.real = 0.0;
-    /*@i2@*/session->last_fixtime.clock.tv_sec = 0;
-    /*@i2@*/session->last_fixtime.clock.tv_nsec = 0;
-#ifdef PPS_ENABLE
-    memset( (void *)&session->ppslast, 0, sizeof(session->ppslast));
-    session->ppscount = 0;
-#if defined(HAVE_SYS_TIMEPPS_H)
-    session->kernelpps_handle = -1;
-#endif /* defined(HAVE_SYS_TIMEPPS_H) */
-#endif /* PPS_ENABLE */
-
     /*@ -mayaliasunique @*/
     if (device != NULL)
 	(void)strlcpy(session->gpsdata.dev.path, device,
@@ -387,8 +367,9 @@ void gpsd_deactivate(struct gps_device_t *session)
 	    session->device_type->mode_switcher(session, 0);
     }
 #endif /* RECONFIGURE_ENABLE */
-    gpsd_report(&session->context->errout, LOG_INF, "closing GPS=%s (%d)\n",
-		session->gpsdata.dev.path, session->gpsdata.gps_fd);
+    gpsd_log(&session->context->errout, LOG_INF,
+	     "closing GPS=%s (%d)\n",
+	     session->gpsdata.dev.path, session->gpsdata.gps_fd);
 #if defined(NMEA2000_ENABLE)
     if (session->sourcetype == source_can)
         (void)nmea2000_close(session);
@@ -401,20 +382,53 @@ void gpsd_deactivate(struct gps_device_t *session)
 			     "DEACTIVATE");
 #ifdef PPS_ENABLE
     /*@-mustfreeonly@*/
-    session->thread_report_hook = NULL;	/* tell any PPS-watcher thread to die */
+    session->pps_thread.report_hook = NULL; /* tell any PPS-watcher thread to die */
 #endif /* PPS_ENABLE */
     /*@-mustfreeonly@*/
     /* mark it inactivated */
     session->gpsdata.online = (timestamp_t)0;
 }
 
-/*@-usereleased -compdef@*/
+#ifdef PPS_ENABLE
+static void ppsthread_log(volatile struct pps_thread_t *pps_thread,
+			  int loglevel, const char *fmt, ...)
+/* shim function to decouple PPS monitor code from the session structure */
+{
+    struct gps_device_t *device = (struct gps_device_t *)pps_thread->context;
+    char buf[BUFSIZ];
+    va_list ap;
+
+    switch (loglevel) {
+    case THREAD_ERROR:
+	loglevel = LOG_ERROR;
+	break;
+    case THREAD_WARN:
+	loglevel = LOG_WARN;
+	break;
+    case THREAD_INF:
+	loglevel = LOG_INF;
+	break;
+    case THREAD_PROG:
+	loglevel = LOG_PROG;
+	break;
+    case THREAD_RAW:
+	loglevel = LOG_RAW;
+	break;
+    }
+
+    buf[0] = '\0';
+    va_start(ap, fmt);
+    gpsd_vlog(&device->context->errout, loglevel, buf, sizeof(buf), fmt, ap);
+    va_end(ap);
+}
+#endif /* PPS_ENABLE */
+
+
+/*@-usereleased -compdef -compmempass@*/
 void gpsd_clear(struct gps_device_t *session)
+/* device has been opened - clear its storage for use */
 {
     session->gpsdata.online = timestamp();
-#ifdef SIRF_ENABLE
-    session->driver.sirf.satcounter = 0;
-#endif /* SIRF_ENABLE */
     lexer_init(&session->lexer);
     session->lexer.errout = session->context->errout;
     // session->gpsdata.online = 0;
@@ -427,18 +441,19 @@ void gpsd_clear(struct gps_device_t *session)
 
     /* clear the private data union */
     memset( (void *)&session->driver, '\0', sizeof(session->driver));
-    /* clear some times */
-    session->last_fixtime.real = 0.0;
-    /*@i2@*/session->last_fixtime.clock.tv_sec = 0;
-    /*@i2@*/session->last_fixtime.clock.tv_nsec = 0;
 #ifdef PPS_ENABLE
-    memset( (void *)&session->ppslast, 0, sizeof(session->ppslast));
-    session->ppscount = 0;
+    /* set up the context structure for the PPS thread monitor */
+    memset((void *)&session->pps_thread, 0, sizeof(session->pps_thread));
+    session->pps_thread.devicefd = session->gpsdata.gps_fd;
+    /*@i2@*/session->pps_thread.devicename = session->gpsdata.dev.path;
+    session->pps_thread.pps_hook = NULL;
+    session->pps_thread.log_hook = ppsthread_log;
+    /*@i4@*/session->pps_thread.context = (void *)session;
 #endif /* PPS_ENABLE */
 
     session->opentime = timestamp();
 }
-/*@+usereleased +compdef@*/
+/*@+usereleased +compdef +compmempass@*/
 
 int gpsd_open(struct gps_device_t *session)
 /* open a device for access to its data */
@@ -449,9 +464,9 @@ int gpsd_open(struct gps_device_t *session)
 	session->gpsdata.gps_fd = netgnss_uri_open(session,
 						   session->gpsdata.dev.path);
 	session->sourcetype = source_tcp;
-	gpsd_report(&session->context->errout, LOG_SPIN,
-		    "netgnss_uri_open(%s) returns socket on fd %d\n",
-		    session->gpsdata.dev.path, session->gpsdata.gps_fd);
+	gpsd_log(&session->context->errout, LOG_SPIN,
+		 "netgnss_uri_open(%s) returns socket on fd %d\n",
+		 session->gpsdata.dev.path, session->gpsdata.gps_fd);
 	return session->gpsdata.gps_fd;
     /* otherwise, could be an TCP data feed */
     } else if (str_starts_with(session->gpsdata.dev.path, "tcp://")) {
@@ -461,22 +476,22 @@ int gpsd_open(struct gps_device_t *session)
 	INVALIDATE_SOCKET(session->gpsdata.gps_fd);
 	port = strchr(server, ':');
 	if (port == NULL) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"Missing colon in TCP feed spec.\n");
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "Missing colon in TCP feed spec.\n");
 	    return -1;
 	}
 	*port++ = '\0';
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "opening TCP feed at %s, port %s.\n", server,
-		    port);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "opening TCP feed at %s, port %s.\n", server,
+		 port);
 	if ((dsock = netlib_connectsock(AF_UNSPEC, server, port, "tcp")) < 0) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"TCP device open error %s.\n",
-			netlib_errstr(dsock));
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "TCP device open error %s.\n",
+		     netlib_errstr(dsock));
 	    return -1;
 	} else
-	    gpsd_report(&session->context->errout, LOG_SPIN, 
-			"TCP device opened on fd %d\n", dsock);
+	    gpsd_log(&session->context->errout, LOG_SPIN, 
+		     "TCP device opened on fd %d\n", dsock);
 	session->gpsdata.gps_fd = dsock;
 	session->sourcetype = source_tcp;
 	return session->gpsdata.gps_fd;
@@ -488,22 +503,22 @@ int gpsd_open(struct gps_device_t *session)
 	INVALIDATE_SOCKET(session->gpsdata.gps_fd);
 	port = strchr(server, ':');
 	if (port == NULL) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"Missing colon in UDP feed spec.\n");
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "Missing colon in UDP feed spec.\n");
 	    return -1;
 	}
 	*port++ = '\0';
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "opening UDP feed at %s, port %s.\n", server,
-		    port);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "opening UDP feed at %s, port %s.\n", server,
+		 port);
 	if ((dsock = netlib_connectsock(AF_UNSPEC, server, port, "udp")) < 0) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"UDP device open error %s.\n",
-			netlib_errstr(dsock));
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "UDP device open error %s.\n",
+		     netlib_errstr(dsock));
 	    return -1;
 	} else
-	    gpsd_report(&session->context->errout, LOG_SPIN,
-			"UDP device opened on fd %d\n", dsock);
+	    gpsd_log(&session->context->errout, LOG_SPIN,
+		     "UDP device opened on fd %d\n", dsock);
 	session->gpsdata.gps_fd = dsock;
 	session->sourcetype = source_udp;
 	return session->gpsdata.gps_fd;
@@ -520,17 +535,17 @@ int gpsd_open(struct gps_device_t *session)
 	    port = DEFAULT_GPSD_PORT;
 	} else
 	    *port++ = '\0';
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "opening remote gpsd feed at %s, port %s.\n",
-		    server, port);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "opening remote gpsd feed at %s, port %s.\n",
+		 server, port);
 	if ((dsock = netlib_connectsock(AF_UNSPEC, server, port, "tcp")) < 0) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"remote gpsd device open error %s.\n",
-			netlib_errstr(dsock));
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "remote gpsd device open error %s.\n",
+		     netlib_errstr(dsock));
 	    return -1;
 	} else
-	    gpsd_report(&session->context->errout, LOG_SPIN,
-			"remote gpsd feed opened on fd %d\n", dsock);
+	    gpsd_log(&session->context->errout, LOG_SPIN,
+		     "remote gpsd feed opened on fd %d\n", dsock);
 	/*@+branchstate +nullpass@*/
 	/* watch to remote is issued when WATCH is */
 	session->gpsdata.gps_fd = dsock;
@@ -571,34 +586,34 @@ int gpsd_activate(struct gps_device_t *session, const int mode)
 	    /*@ -mustfreeonly @*/
 	    for (dp = gpsd_drivers; *dp; dp++) {
 		if ((*dp)->probe_detect != NULL) {
-		    gpsd_report(&session->context->errout, LOG_PROG,
-				"Probing \"%s\" driver...\n",
-				 (*dp)->type_name);
+		    gpsd_log(&session->context->errout, LOG_PROG,
+			     "Probing \"%s\" driver...\n",
+			     (*dp)->type_name);
 		    /* toss stale data */
 		    (void)tcflush(session->gpsdata.gps_fd, TCIOFLUSH);
 		    if ((*dp)->probe_detect(session) != 0) {
-			gpsd_report(&session->context->errout, LOG_PROG,
-				    "Probe found \"%s\" driver...\n",
-				     (*dp)->type_name);
+			gpsd_log(&session->context->errout, LOG_PROG,
+				 "Probe found \"%s\" driver...\n",
+				 (*dp)->type_name);
 			session->device_type = *dp;
 			gpsd_assert_sync(session);
 			goto foundit;
 		    } else
-			gpsd_report(&session->context->errout, LOG_PROG,
-				    "Probe not found \"%s\" driver...\n",
-			             (*dp)->type_name);
+			gpsd_log(&session->context->errout, LOG_PROG,
+				 "Probe not found \"%s\" driver...\n",
+				 (*dp)->type_name);
 		}
 	    }
 	    /*@ +mustfreeonly @*/
-	    gpsd_report(&session->context->errout, LOG_PROG,
-			"no probe matched...\n");
+	    gpsd_log(&session->context->errout, LOG_PROG,
+		     "no probe matched...\n");
 	}
       foundit:
 #endif /* NON_NMEA_ENABLE */
 	gpsd_clear(session);
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "gpsd_activate(%d): activated GPS (fd %d)\n",
-		    session->mode, session->gpsdata.gps_fd);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "gpsd_activate(%d): activated GPS (fd %d)\n",
+		 session->mode, session->gpsdata.gps_fd);
 	/*
 	 * We might know the device's type, but we shouldn't assume it has
 	 * retained its settings.  A revert hook might well have undone
@@ -716,7 +731,7 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
 
     memset(satpos, 0, sizeof(satpos));
 
-    gpsd_report(errout, LOG_INF, "Sats used (%d):\n", gpsdata->satellites_used);
+    gpsd_log(errout, LOG_INF, "Sats used (%d):\n", gpsdata->satellites_used);
     for (n = k = 0; k < gpsdata->satellites_visible; k++) {
 	if (gpsdata->skyview[k].used && !SBAS_PRN(gpsdata->skyview[k].PRN))
 	{
@@ -727,11 +742,11 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
 		* cos(sp->elevation * DEG_2_RAD);
 	    satpos[n][2] = sin(sp->elevation * DEG_2_RAD);
 	    satpos[n][3] = 1;
-	    gpsd_report(errout, LOG_INF, "PRN=%3d az=%3d el=%2d (%f, %f, %f)\n",
-			gpsdata->skyview[k].PRN,
-			gpsdata->skyview[k].azimuth,
-			gpsdata->skyview[k].elevation,
-			satpos[n][0], satpos[n][1], satpos[n][2]);
+	    gpsd_log(errout, LOG_INF, "PRN=%3d az=%3d el=%2d (%f, %f, %f)\n",
+		     gpsdata->skyview[k].PRN,
+		     gpsdata->skyview[k].azimuth,
+		     gpsdata->skyview[k].elevation,
+		     satpos[n][0], satpos[n][1], satpos[n][2]);
 	    n++;
 	}
     }
@@ -739,9 +754,9 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
     /* If we don't have 4 satellites then we don't have enough information to calculate DOPS */
     if (n < 4) {
 #ifdef __UNUSED__
-	gpsd_report(errout, LOG_DATA + 2,
-		    "Not enough satellites available %d < 4:\n",
-		    n);
+	gpsd_log(errout, LOG_DATA + 2,
+		 "Not enough satellites available %d < 4:\n",
+		 n);
 #endif /* __UNUSED__ */
 	return 0;		/* Is this correct return code here? or should it be ERROR_SET */
     }
@@ -750,10 +765,10 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
     memset(inv, 0, sizeof(inv));
 
 #ifdef __UNUSED__
-    gpsd_report(errout, LOG_INF, "Line-of-sight matrix:\n");
+    gpsd_log(errout, LOG_INF, "Line-of-sight matrix:\n");
     for (k = 0; k < n; k++) {
-	gpsd_report(errout, LOG_INF, "%f %f %f %f\n",
-		    satpos[k][0], satpos[k][1], satpos[k][2], satpos[k][3]);
+	gpsd_log(errout, LOG_INF, "%f %f %f %f\n",
+		 satpos[k][0], satpos[k][1], satpos[k][2], satpos[k][3]);
     }
 #endif /* __UNUSED__ */
 
@@ -767,10 +782,10 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
     }
 
 #ifdef __UNUSED__
-    gpsd_report(errout, LOG_INF, "product:\n");
+    gpsd_log(errout, LOG_INF, "product:\n");
     for (k = 0; k < 4; k++) {
-	gpsd_report(errout, LOG_INF, "%f %f %f %f\n",
-		    prod[k][0], prod[k][1], prod[k][2], prod[k][3]);
+	gpsd_log(errout, LOG_INF, "%f %f %f %f\n",
+		 prod[k][0], prod[k][1], prod[k][2], prod[k][3]);
     }
 #endif /* __UNUSED__ */
 
@@ -780,18 +795,18 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
 	 * Note: this will print garbage unless all the subdeterminants
 	 * are computed in the invert() function.
 	 */
-	gpsd_report(errout, LOG_RAW, "inverse:\n");
+	gpsd_log(errout, LOG_RAW, "inverse:\n");
 	for (k = 0; k < 4; k++) {
-	    gpsd_report(errout, LOG_RAW,
-			"%f %f %f %f\n",
-			inv[k][0], inv[k][1], inv[k][2], inv[k][3]);
+	    gpsd_log(errout, LOG_RAW,
+		     "%f %f %f %f\n",
+		     inv[k][0], inv[k][1], inv[k][2], inv[k][3]);
 	}
 #endif /* __UNUSED__ */
     } else {
 #ifndef USE_QT
-	gpsd_report(errout, LOG_DATA,
-		    "LOS matrix is singular, can't calculate DOPs - source '%s'\n",
-		    gpsdata->dev.path);
+	gpsd_log(errout, LOG_DATA,
+		 "LOS matrix is singular, can't calculate DOPs - source '%s'\n",
+		 gpsdata->dev.path);
 #endif
 	return 0;
     }
@@ -805,10 +820,11 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
     gdop = sqrt(inv[0][0] + inv[1][1] + inv[2][2] + inv[3][3]);
 
 #ifndef USE_QT
-    gpsd_report(errout, LOG_DATA,
-		"DOPS computed/reported: X=%f/%f, Y=%f/%f, H=%f/%f, V=%f/%f, P=%f/%f, T=%f/%f, G=%f/%f\n",
-		xdop, dop->xdop, ydop, dop->ydop, hdop, dop->hdop, vdop,
-		dop->vdop, pdop, dop->pdop, tdop, dop->tdop, gdop, dop->gdop);
+    gpsd_log(errout, LOG_DATA,
+	     "DOPS computed/reported: X=%f/%f, Y=%f/%f, H=%f/%f, V=%f/%f, "
+	     "P=%f/%f, T=%f/%f, G=%f/%f\n",
+	     xdop, dop->xdop, ydop, dop->ydop, hdop, dop->hdop, vdop,
+	     dop->vdop, pdop, dop->pdop, tdop, dop->tdop, gdop, dop->gdop);
 #endif
 
     /*@ -usedef @*/
@@ -1001,13 +1017,10 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
 /* await data from any socket in the all_fds set */
 {
     int status;
-#ifdef COMPAT_SELECT
-    struct timeval tv;
-#endif /* COMPAT_SELECT */
 
     FD_ZERO(efds);
     (void)memcpy((char *)rfds, (char *)all_fds, sizeof(fd_set));
-    gpsd_report(errout, LOG_RAW + 2, "select waits\n");
+    gpsd_log(errout, LOG_RAW + 2, "select waits\n");
     /*
      * Poll for user commands or GPS data.  The timeout doesn't
      * actually matter here since select returns whenever one of
@@ -1016,20 +1029,14 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
      * select(2) has to poll here as small as possible (for
      * low-clock-rate SBCs and the like).
      *
-     * pselect() is preferable, when we can have it, to eliminate
+     * pselect() is preferable to vanilla select, to eliminate
      * the once-per-second wakeup when no sensors are attached.
      * This cuts power consumption.
      */
     /*@ -usedef -nullpass @*/
     errno = 0;
 
-#ifdef COMPAT_SELECT
-    tv.tv_sec = 1;
-    tv.tv_usec = 0;
-    status = select(maxfd + 1, rfds, NULL, NULL, &tv);
-#else
     status = pselect(maxfd + 1, rfds, NULL, NULL, NULL, NULL);
-#endif
     if (status == -1) {
 	if (errno == EINTR)
 	    return AWAIT_NOT_READY;
@@ -1046,7 +1053,7 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
 		}
 	    return AWAIT_NOT_READY;
 	} else {
-	    gpsd_report(errout, LOG_ERROR, "select: %s\n", strerror(errno));
+	    gpsd_log(errout, LOG_ERROR, "select: %s\n", strerror(errno));
 	    return AWAIT_FAILED;
 	}
     }
@@ -1064,9 +1071,9 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
 	for (i = 0; i < (int)FD_SETSIZE; i++)
 	    if (FD_ISSET(i, rfds))
 		str_appendf(dbuf, sizeof(dbuf), " %d ", i);
-	gpsd_report(errout, LOG_SPIN,
-		    "select() {%s} at %f (errno %d)\n",
-		    dbuf, timestamp(), errno);
+	gpsd_log(errout, LOG_SPIN,
+		 "select() {%s} at %f (errno %d)\n",
+		 dbuf, timestamp(), errno);
     }
 
     return AWAIT_GOT_INPUT;
@@ -1169,11 +1176,11 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	    double gap = now - session->lexer.start_time;
 
 	    if (gap > min_cycle)
-		gpsd_report(&session->context->errout, LOG_WARN,
-			    "cycle-start detector failed.\n");
+		gpsd_log(&session->context->errout, LOG_WARN,
+			 "cycle-start detector failed.\n");
 	    else if (gap > quiet_time) {
-		gpsd_report(&session->context->errout, LOG_PROG,
-			    "transmission pause of %f\n", gap);
+		gpsd_log(&session->context->errout, LOG_PROG,
+			 "transmission pause of %f\n", gap);
 		session->sor = now;
 		session->lexer.start_char = session->lexer.char_counter;
 	    }
@@ -1192,23 +1199,23 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
     if (session->device_type != NULL) {
 	newlen = session->device_type->get_packet(session);
 	/* coverity[deref_ptr] */
-	gpsd_report(&session->context->errout, LOG_RAW,
-		    "%s is known to be %s\n",
-		    session->gpsdata.dev.path,
-		    session->device_type->type_name);
+	gpsd_log(&session->context->errout, LOG_RAW,
+		 "%s is known to be %s\n",
+		 session->gpsdata.dev.path,
+		 session->device_type->type_name);
     } else {
 	newlen = generic_get(session);
     }
 
     /* update the scoreboard structure from the GPS */
-    gpsd_report(&session->context->errout, LOG_RAW + 2,
-		"%s sent %zd new characters\n",
-		session->gpsdata.dev.path, newlen);
+    gpsd_log(&session->context->errout, LOG_RAW + 2,
+	     "%s sent %zd new characters\n",
+	     session->gpsdata.dev.path, newlen);
     if (newlen < 0) {		/* read error */
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "GPS on %s returned error %zd (%lf sec since data)\n",
-		    session->gpsdata.dev.path, newlen,
-		    timestamp() - session->gpsdata.online);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "GPS on %s returned error %zd (%lf sec since data)\n",
+		 session->gpsdata.dev.path, newlen,
+		 timestamp() - session->gpsdata.online);
 	session->gpsdata.online = (timestamp_t)0;
 	return ERROR_SET;
     } else if (newlen == 0) {		/* zero length read, possible EOF */
@@ -1217,26 +1224,26 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	 * wrong time...
 	 */
 	if (session->gpsdata.online > 0 && timestamp() - session->gpsdata.online >= session->gpsdata.dev.cycle * 2) {
-	    gpsd_report(&session->context->errout, LOG_INF,
-			"GPS on %s is offline (%lf sec since data)\n",
-			session->gpsdata.dev.path,
-			timestamp() - session->gpsdata.online);
+	    gpsd_log(&session->context->errout, LOG_INF,
+		     "GPS on %s is offline (%lf sec since data)\n",
+		     session->gpsdata.dev.path,
+		     timestamp() - session->gpsdata.online);
 	    session->gpsdata.online = (timestamp_t)0;
 	}
 	return NODATA_IS;
     } else /* (newlen > 0) */ {
-	gpsd_report(&session->context->errout, LOG_RAW,
-		    "packet sniff on %s finds type %d\n",
-		    session->gpsdata.dev.path, session->lexer.type);
+	gpsd_log(&session->context->errout, LOG_RAW,
+		 "packet sniff on %s finds type %d\n",
+		 session->gpsdata.dev.path, session->lexer.type);
 	if (session->lexer.type == COMMENT_PACKET) {
 	    if (strcmp((const char *)session->lexer.outbuffer, "# EOF\n") == 0) {
-		gpsd_report(&session->context->errout, LOG_PROG,
-			    "synthetic EOF\n");
+		gpsd_log(&session->context->errout, LOG_PROG,
+			 "synthetic EOF\n");
 		return EOF_IS;
 	    }
 	    else
-		gpsd_report(&session->context->errout, LOG_PROG,
-			    "comment, sync lock deferred\n");
+		gpsd_log(&session->context->errout, LOG_PROG,
+			 "comment, sync lock deferred\n");
 	    /* FALL THROUGH */
 	} else if (session->lexer.type > COMMENT_PACKET) {
 	    if (session->device_type == NULL)
@@ -1276,9 +1283,9 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 
 		for (dp = gpsd_drivers; *dp; dp++)
 		    if (session->lexer.type == (*dp)->packet_type) {
-			gpsd_report(&session->context->errout, LOG_PROG,
-				    "switching to match packet type %d: %s\n",
-				    session->lexer.type, gpsd_prettydump(session));
+			gpsd_log(&session->context->errout, LOG_PROG,
+				 "switching to match packet type %d: %s\n",
+				 session->lexer.type, gpsd_prettydump(session));
 			(void)gpsd_switch_driver(session, (*dp)->type_name);
 			break;
 		    }
@@ -1288,26 +1295,26 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	    session->gpsdata.dev.driver_mode = (session->lexer.type > NMEA_PACKET) ? MODE_BINARY : MODE_NMEA;
 	    /* FALL THROUGH */
 	} else if (hunt_failure(session) && !gpsd_next_hunt_setting(session)) {
-	    gpsd_report(&session->context->errout, LOG_INF,
-			"hunt on %s failed (%lf sec since data)\n",
-			session->gpsdata.dev.path,
-			timestamp() - session->gpsdata.online);
+	    gpsd_log(&session->context->errout, LOG_INF,
+		     "hunt on %s failed (%lf sec since data)\n",
+		     session->gpsdata.dev.path,
+		     timestamp() - session->gpsdata.online);
 	    return ERROR_SET;
 	}
     }
 
     if (session->lexer.outbuflen == 0) {	/* got new data, but no packet */
-	gpsd_report(&session->context->errout, LOG_RAW + 3,
-		    "New data on %s, not yet a packet\n",
-		    session->gpsdata.dev.path);
+	gpsd_log(&session->context->errout, LOG_RAW + 3,
+		 "New data on %s, not yet a packet\n",
+		 session->gpsdata.dev.path);
 	return ONLINE_SET;
     } else {			/* we have recognized a packet */
 	gps_mask_t received = PACKET_SET;
 	session->gpsdata.online = timestamp();
 
-	gpsd_report(&session->context->errout, LOG_RAW + 3,
-		    "Accepted packet on %s.\n",
-		    session->gpsdata.dev.path);
+	gpsd_log(&session->context->errout, LOG_RAW + 3,
+		 "Accepted packet on %s.\n",
+		 session->gpsdata.dev.path);
 
 	/* track the packet count since achieving sync on the device */
 	if (driver_change 
@@ -1316,12 +1323,12 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 
 	    /*@-nullderef@*/
 	    /* coverity[var_deref_op] */
-	    gpsd_report(&session->context->errout, LOG_INF,
-			"%s identified as type %s, %f sec @ %ubps\n",
-			session->gpsdata.dev.path,
-			session->device_type->type_name,
-			timestamp() - session->opentime,
-			(unsigned int)speed);
+	    gpsd_log(&session->context->errout, LOG_INF,
+		     "%s identified as type %s, %f sec @ %ubps\n",
+		     session->gpsdata.dev.path,
+		     session->device_type->type_name,
+		     timestamp() - session->opentime,
+		     (unsigned int)speed);
 	    /*@+nullderef@*/
 
 	    /* fire the init_query method */
@@ -1362,11 +1369,11 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	 * level does not actually require it.
 	 */
 	if (session->context->errout.debug >= LOG_RAW)
-	    gpsd_report(&session->context->errout, LOG_RAW,
-			"raw packet of type %d, %zd:%s\n",
-			session->lexer.type,
-			session->lexer.outbuflen,
-			gpsd_prettydump(session));
+	    gpsd_log(&session->context->errout, LOG_RAW,
+		     "raw packet of type %d, %zd:%s\n",
+		     session->lexer.type,
+		     session->lexer.outbuflen,
+		     gpsd_prettydump(session));
 
 	/* Get data from current packet into the fix structure */
 	if (session->lexer.type != COMMENT_PACKET)
@@ -1387,9 +1394,9 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	    && session->last_controller != NULL)
 	{
 	    session->device_type = session->last_controller;
-	    gpsd_report(&session->context->errout, LOG_PROG,
-			"reverted to %s driver...\n",
-			session->device_type->type_name);
+	    gpsd_log(&session->context->errout, LOG_PROG,
+		     "reverted to %s driver...\n",
+		     session->device_type->type_name);
 	}
 	/*@+mustfreeonly@*/
 #endif /* RECONFIGURE_ENABLE */
@@ -1426,12 +1433,13 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	/* don't downgrade mode if holding previous fix */
 	if (session->gpsdata.fix.mode > session->newdata.mode)
 	    session->gpsdata.set &= ~MODE_SET;
-	//gpsd_report(&session->context->errout, LOG_PROG,
+	//gpsd_log(&session->context->errout, LOG_PROG,
 	//              "transfer mask: %02x\n", session->gpsdata.set);
 	gps_merge_fix(&session->gpsdata.fix,
 		      session->gpsdata.set, &session->newdata);
 #ifndef NOFLOATS_ENABLE
-	gpsd_error_model(session, &session->gpsdata.fix, &session->oldfix);
+	/*@i1@*/gpsd_error_model(session,
+				 &session->gpsdata.fix, &session->oldfix);
 #endif /* NOFLOATS_ENABLE */
 
 	/*@+nullderef -nullpass@*/
@@ -1465,11 +1473,11 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	/*@+relaxtypes +longunsignedintegral@*/
 	if ((session->gpsdata.set & TIME_SET) != 0) {
 	    if (session->newdata.time > time(NULL) + (60 * 60 * 24 * 365))
-		gpsd_report(&session->context->errout, LOG_WARN,
-			    "date more than a year in the future!\n");
+		gpsd_log(&session->context->errout, LOG_WARN,
+			 "date more than a year in the future!\n");
 	    else if (session->newdata.time < 0)
-		gpsd_report(&session->context->errout, LOG_ERROR,
-			    "date is negative!\n");
+		gpsd_log(&session->context->errout, LOG_ERROR,
+			 "date is negative!\n");
 	}
 	/*@-relaxtypes -longunsignedintegral@*/
 
@@ -1487,8 +1495,8 @@ int gpsd_multipoll(const bool data_ready,
     {
 	int fragments;
 
-	gpsd_report(&device->context->errout, LOG_RAW + 1, 
-		    "polling %d\n", device->gpsdata.gps_fd);
+	gpsd_log(&device->context->errout, LOG_RAW + 1, 
+		 "polling %d\n", device->gpsdata.gps_fd);
 
 #ifdef NETFEED_ENABLE
 	/*
@@ -1500,8 +1508,8 @@ int gpsd_multipoll(const bool data_ready,
 
 	    (void)ntrip_open(device, "");
 	    if (device->ntrip.conn_state == ntrip_conn_err) {
-		gpsd_report(&device->context->errout, LOG_WARN,
-			    "connection to ntrip server failed\n");
+		gpsd_log(&device->context->errout, LOG_WARN,
+			 "connection to ntrip server failed\n");
 		device->ntrip.conn_state = ntrip_conn_init;
 		return DEVICE_ERROR;
 	    } else {
@@ -1514,15 +1522,15 @@ int gpsd_multipoll(const bool data_ready,
 	    gps_mask_t changed = gpsd_poll(device);
 
 	    if (changed == EOF_IS) {
-		gpsd_report(&device->context->errout, LOG_WARN,
-			    "device signed off %s\n",
-			    device->gpsdata.dev.path);
+		gpsd_log(&device->context->errout, LOG_WARN,
+			 "device signed off %s\n",
+			 device->gpsdata.dev.path);
 		return DEVICE_EOF;
 	    } else if (changed == ERROR_SET) {
-		gpsd_report(&device->context->errout, LOG_WARN,
-			    "device read of %s returned error or packet sniffer failed sync (flags %s)\n",
-			    device->gpsdata.dev.path,
-			    gps_maskdump(changed));
+		gpsd_log(&device->context->errout, LOG_WARN,
+			 "device read of %s returned error or packet sniffer failed sync (flags %s)\n",
+			 device->gpsdata.dev.path,
+			 gps_maskdump(changed));
 		return DEVICE_ERROR;
 	    } else if (changed == NODATA_IS) {
 		/*
@@ -1530,21 +1538,21 @@ int gpsd_multipoll(const bool data_ready,
 		 * fd may have been in an end-of-file condition on select.
 		 */
 		if (fragments == 0) {
-		    gpsd_report(&device->context->errout, LOG_DATA,
-				"%s returned zero bytes\n",
-				device->gpsdata.dev.path);
+		    gpsd_log(&device->context->errout, LOG_DATA,
+			     "%s returned zero bytes\n",
+			     device->gpsdata.dev.path);
 		    if (device->zerokill) {
 			/* failed timeout-and-reawake, kill it */
 			gpsd_deactivate(device);
 			if (device->ntrip.works) {
 			    device->ntrip.works = false; // reset so we try this once only
 			    if (gpsd_activate(device, O_CONTINUE) < 0) {
-				gpsd_report(&device->context->errout, LOG_WARN,
-					    "reconnect to ntrip server failed\n");
+				gpsd_log(&device->context->errout, LOG_WARN,
+					 "reconnect to ntrip server failed\n");
 				return DEVICE_ERROR;
 			    } else {
-				gpsd_report(&device->context->errout, LOG_INFO,
-					    "reconnecting to ntrip server\n");
+				gpsd_log(&device->context->errout, LOG_INFO,
+					 "reconnecting to ntrip server\n");
 				return DEVICE_READY;
 			    }
 			}
@@ -1555,9 +1563,9 @@ int gpsd_multipoll(const bool data_ready,
 			 * Disable listening to this fd for long enough
 			 * that the buffer can fill up again.
 			 */
-			gpsd_report(&device->context->errout, LOG_DATA,
-				    "%s will be repolled in %f seconds\n",
-				    device->gpsdata.dev.path, reawake_time);
+			gpsd_log(&device->context->errout, LOG_DATA,
+				 "%s will be repolled in %f seconds\n",
+				 device->gpsdata.dev.path, reawake_time);
 			device->reawake = timestamp() + reawake_time;
 			return DEVICE_UNREADY;
 		    }
@@ -1582,15 +1590,15 @@ int gpsd_multipoll(const bool data_ready,
 	    /* conditional prevents mask dumper from eating CPU */
 	    if (device->context->errout.debug >= LOG_DATA) {
 		if (device->lexer.type == BAD_PACKET)
-		    gpsd_report(&device->context->errout, LOG_DATA,
-				"packet with bad checksum from %s\n",
-				device->gpsdata.dev.path);
+		    gpsd_log(&device->context->errout, LOG_DATA,
+			     "packet with bad checksum from %s\n",
+			     device->gpsdata.dev.path);
 		else
-		    gpsd_report(&device->context->errout, LOG_DATA,
-				"packet type %d from %s with %s\n",
-				device->lexer.type,
-				device->gpsdata.dev.path,
-				gps_maskdump(device->gpsdata.set));
+		    gpsd_log(&device->context->errout, LOG_DATA,
+			     "packet type %d from %s with %s\n",
+			     device->lexer.type,
+			     device->gpsdata.dev.path,
+			     gps_maskdump(device->gpsdata.set));
 	    }
 
 
@@ -1615,9 +1623,9 @@ int gpsd_multipoll(const bool data_ready,
     }
     else if (device->reawake>0 && timestamp()>device->reawake) {
 	/* device may have had a zero-length read */
-	gpsd_report(&device->context->errout, LOG_DATA,
-		    "%s reawakened after zero-length read\n",
-		    device->gpsdata.dev.path);
+	gpsd_log(&device->context->errout, LOG_DATA,
+		 "%s reawakened after zero-length read\n",
+		 device->gpsdata.dev.path);
 	device->reawake = (timestamp_t)0;
 	device->zerokill = true;
 	return DEVICE_READY;
@@ -1658,13 +1666,7 @@ void ntp_latch(struct gps_device_t *device, struct timedelta_t /*@out@*/*td)
     /* this should be an invariant of the way this function is called */
     assert(isnan(device->newdata.time)==0);
 
-#ifdef HAVE_CLOCK_GETTIME
-    /*@i2@*/(void)clock_gettime(CLOCK_REALTIME, &td->clock);
-#else
-    struct timeval clock_tv;
-    (void)gettimeofday(&clock_tv, NULL);
-    TVTOTS(&td->clock, &clock_tv);
-#endif /* HAVE_CLOCK_GETTIME */
+    (void)clock_gettime(CLOCK_REALTIME, &td->clock);
     fix_time = device->newdata.time;
 
 #ifdef TIMEHINT_ENABLE
@@ -1689,7 +1691,7 @@ void ntp_latch(struct gps_device_t *device, struct timedelta_t /*@out@*/*td)
 #ifdef PPS_ENABLE
     /* thread-safe update */
     /*@-compdef@*/
-    pps_thread_stash_fixtime(device, device->newdata.time, td->clock);
+    pps_thread_fixin(&device->pps_thread, td);
     /*@+compdef@*/
 #endif /* PPS_ENABLE */
 }
