@@ -282,9 +282,6 @@ static void sirf_update(void)
     size_t len;
     uint8_t dgps;
     char tbuf[JSON_DATE_MAX+1];
-#ifdef PPS_ENABLE
-    struct timedrift_t drift;
-#endif /* PPS_ENABLE */
 
     /* splint pacification */
     assert(mid2win!=NULL && mid27win != NULL);
@@ -390,7 +387,7 @@ static void sirf_update(void)
 
     case 0x07:			/* Response - Clock Status Data */
 	display(mid7win, 1, 5, "%2d", getub(buf, 7));	/* SVs */
-	display(mid7win, 1, 16, "%lu", getbeu32(buf, 8));	/* Clock drift */
+	display(mid7win, 1, 16, "%lu", getbeu32(buf, 8));	/* Clock ppstimes */
 	display(mid7win, 1, 29, "%lu", getbeu32(buf, 12));	/* Clock Bias */
 	display(mid7win, 2, 11, "%lu", getbeu32(buf, 16));	/* Estimated Time */
 	monitor_log("CSD 0x07=");
@@ -588,25 +585,7 @@ static void sirf_update(void)
     /*@ +nullpass -nullderef @*/
 
 #ifdef PPS_ENABLE
-    /*@-compdef@*/
-    /*@-type -noeffect@*/ /* splint is confused about struct timespec */
-    if (pps_thread_lastpps(&session, &drift) > 0) {
-	/* NOTE: cannot use double here due to precision requirements */
-	struct timespec timedelta;
-	TS_SUB( &timedelta, &drift.clock, &drift.real);
-        if ( 86400 < (long)labs(timedelta.tv_sec) ) {
-	    /* more than one day off, overflow */
-            /* need a bigger field to show it */
-	    (void)mvwprintw(mid7win, 2, 28, "> 1 day");
-        } else {
-	    char buf2[TIMESPEC_LEN];
-	    timespec_str( &timedelta, buf2, sizeof(buf2) );
-	    (void)mvwprintw(mid7win, 2, 32, "%s", buf2);
-        }
-	(void)wnoutrefresh(mid7win);
-    }
-    /*@+type +noeffect@*/
-    /*@+compdef@*/
+    pps_update(mid7win, 2, 32);
 #endif /* PPS_ENABLE */
 }
 
