@@ -45,9 +45,9 @@ int netgnss_uri_open(struct gps_device_t *dev, char *netgnss_service)
 #ifndef REQUIRE_DGNSS_PROTO
     return dgpsip_open(dev, netgnss_service);
 #else
-    gpsd_report(&dev->context.errout, LOG_ERROR,
-		"Unknown or unspecified DGNSS protocol for service %s\n",
-		netgnss_service);
+    gpsd_log(&dev->context.errout, LOG_ERROR,
+	     "Unknown or unspecified DGNSS protocol for service %s\n",
+	     netgnss_service);
     return -1;
 #endif
 }
