@@ -94,6 +94,9 @@ PERMISSIONS
  *      $GP -- Global Positioning System.
  *      $GL -- GLONASS, according to IEIC 61162-1
  *      $GN -- Mixed GPS and GLONASS data, according to IEIC 61162-1
+ *      $BD -- Beidou
+ *      $GB -- Beidou
+ *      $QZ -- QZSS GPS augmentation system
  *      $II -- Integrated Instrumentation (Raytheon's SeaTalk system).
  *      $IN -- Integrated Navigation (Garmin uses this).
  *      $WI -- Weather instrument (Airmar PB200, Radio Ocean ROWIND, Vaisala WXT520).
@@ -199,11 +202,11 @@ static bool character_pushback(struct gps_lexer_t *lexer, unsigned int newstate)
     if (lexer->errout.debug >= LOG_RAW + 2)
     {
 	unsigned char c = *lexer->inbufptr;
-	gpsd_report(&lexer->errout, LOG_RAW + 2,
-		"%08ld: character '%c' [%02x]  pushed back, state set to %s\n",
-		lexer->char_counter,
-		(isprint((int)c) ? c : '.'), c,
-		state_table[lexer->state]);
+	gpsd_log(&lexer->errout, LOG_RAW + 2,
+		 "%08ld: character '%c' [%02x]  pushed back, state set to %s\n",
+		 lexer->char_counter,
+		 (isprint((int)c) ? c : '.'), c,
+		 state_table[lexer->state]);
     }
 
     return false;
@@ -369,6 +372,10 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	    lexer->state = SOUNDER_LEAD_1;
 	else if (c == 'Y')
 	    lexer->state = TRANSDUCER_LEAD_1;
+	else if (c == 'B')
+	    lexer->state = BEIDOU_LEAD_1;
+	else if (c == 'Q')
+	    lexer->state = QZSS_LEAD_1;
 #ifdef OCEANSERVER_ENABLE
 	else if (c == 'C')
 	    lexer->state = NMEA_LEADER_END;
@@ -380,8 +387,10 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	/*
 	 * $GP == GPS, $GL = GLONASS only, $GN = mixed GPS and GLONASS,
 	 * according to NMEA (IEIC 61162-1) DRAFT 02/06/2009.
+	 * We have a log from China with a Beidou device using $GB
+	 * rather than $BD.
 	 */
-	if (c == 'P' || c == 'N' || c == 'L')
+	if (c == 'B' || c == 'P' || c == 'N' || c == 'L')
 	    lexer->state = NMEA_LEADER_END;
 	else
 	    (void) character_pushback(lexer, GROUND_STATE);
@@ -604,6 +613,18 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	else
 	    return character_pushback(lexer, GROUND_STATE);
 	break;
+    case BEIDOU_LEAD_1:
+	if (c == 'D')		/* Beidou leader accepted */
+	    lexer->state = NMEA_LEADER_END;
+	else
+	    return character_pushback(lexer, GROUND_STATE);
+	break;
+    case QZSS_LEAD_1:
+	if (c == 'Z')		/* QZSS leader accepted */
+	    lexer->state = NMEA_LEADER_END;
+	else
+	    return character_pushback(lexer, GROUND_STATE);
+	break;
 #ifdef TRIPMATE_ENABLE
     case ASTRAL_1:
 	if (c == 'S') {
@@ -950,9 +971,9 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	     n++)
 	    csum ^= lexer->inbuffer[n];
 	if (csum != c) {
-	    gpsd_report(&lexer->errout, LOG_IO,
-			"Navcom packet type 0x%hhx bad checksum 0x%hhx, expecting 0x%x\n",
-			lexer->inbuffer[3], csum, c);
+	    gpsd_log(&lexer->errout, LOG_IO,
+		     "Navcom packet type 0x%hhx bad checksum 0x%hhx, expecting 0x%x\n",
+		     lexer->inbuffer[3], csum, c);
 	    lexer->state = GROUND_STATE;
 	    break;
 	}
@@ -1036,16 +1057,16 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	short sum = getword(0) + getword(1) + getword(2) + getword(3);
 	sum *= -1;
 	if (sum != getword(4)) {
-	    gpsd_report(&lexer->errout, LOG_IO,
-			"Zodiac Header checksum 0x%hx expecting 0x%hx\n",
-			sum, getword(4));
+	    gpsd_log(&lexer->errout, LOG_IO,
+		     "Zodiac Header checksum 0x%hx expecting 0x%hx\n",
+		     sum, getword(4));
 	    lexer->state = GROUND_STATE;
 	    break;
 	}
     }
-	gpsd_report(&lexer->errout, LOG_RAW + 1,
-		    "Zodiac header id=%hd len=%hd flags=%hx\n",
-		    getword(1), getword(2), getword(3));
+	gpsd_log(&lexer->errout, LOG_RAW + 1,
+		 "Zodiac header id=%hd len=%hd flags=%hx\n",
+		 getword(1), getword(2), getword(3));
 #undef getword
 	if (lexer->length == 0) {
 	    lexer->state = ZODIAC_RECOGNIZED;
@@ -1175,8 +1196,8 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	if ((c == '>') && (lexer->inbufptr[0] == '<') &&
 	    (lexer->inbufptr[1] == '!')) {
 	    lexer->state = ITALK_RECOGNIZED;
-	    gpsd_report(&lexer->errout, LOG_IO,
-			"ITALK: trying to process runt packet\n");
+	    gpsd_log(&lexer->errout, LOG_IO,
+		     "ITALK: trying to process runt packet\n");
 	    break;
 	} else if (--lexer->length == 0)
 	    lexer->state = ITALK_DELIVERED;
@@ -1331,9 +1352,9 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	    lexer->state = JSON_STRINGLITERAL;
 	    lexer->json_after = JSON_END_ATTRIBUTE;
 	} else {
-	    gpsd_report(&lexer->errout, LOG_RAW + 2,
-			"%08ld: missing attribute start after header\n",
-			lexer->char_counter);
+	    gpsd_log(&lexer->errout, LOG_RAW + 2,
+		     "%08ld: missing attribute start after header\n",
+		     lexer->char_counter);
 	    lexer->state = GROUND_STATE;
 	}
 	break;
@@ -1423,17 +1444,17 @@ static void packet_accept(struct gps_lexer_t *lexer, int packet_type)
 	lexer->type = packet_type;
 	if (lexer->errout.debug >= LOG_RAW+1) {
 	    char scratchbuf[MAX_PACKET_LENGTH*2+1];
-	    gpsd_report(&lexer->errout, LOG_RAW+1,
-			"Packet type %d accepted %zu = %s\n",
-			packet_type, packetlen,
-			gpsd_packetdump(scratchbuf,  sizeof(scratchbuf),
-					(char *)lexer->outbuffer,
-					lexer->outbuflen));
+	    gpsd_log(&lexer->errout, LOG_RAW+1,
+		     "Packet type %d accepted %zu = %s\n",
+		     packet_type, packetlen,
+		     gpsd_packetdump(scratchbuf,  sizeof(scratchbuf),
+				     (char *)lexer->outbuffer,
+				     lexer->outbuflen));
 	}
     } else {
-	gpsd_report(&lexer->errout, LOG_ERROR,
-		    "Rejected too long packet type %d len %zu\n",
-		    packet_type, packetlen);
+	gpsd_log(&lexer->errout, LOG_ERROR,
+		 "Rejected too long packet type %d len %zu\n",
+		 packet_type, packetlen);
     }
 }
 
@@ -1446,10 +1467,10 @@ static void packet_discard(struct gps_lexer_t *lexer)
     lexer->inbuflen = remaining;
     if (lexer->errout.debug >= LOG_RAW+1) {
 	char scratchbuf[MAX_PACKET_LENGTH*2+1];
-	gpsd_report(&lexer->errout, LOG_RAW + 1,
-		    "Packet discard of %zu, chars remaining is %zu = %s\n",
-		    discard, remaining,
-		    gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
+	gpsd_log(&lexer->errout, LOG_RAW + 1,
+		 "Packet discard of %zu, chars remaining is %zu = %s\n",
+		 discard, remaining,
+		 gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
 				    (char *)lexer->inbuffer, lexer->inbuflen));
     }
 }
@@ -1461,10 +1482,10 @@ static void character_discard(struct gps_lexer_t *lexer)
     lexer->inbufptr = lexer->inbuffer;
     if (lexer->errout.debug >= LOG_RAW+1) {
 	char scratchbuf[MAX_PACKET_LENGTH*2+1];
-	gpsd_report(&lexer->errout, LOG_RAW + 1,
-		    "Character discarded, buffer %zu chars = %s\n",
-		    lexer->inbuflen,
-		    gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
+	gpsd_log(&lexer->errout, LOG_RAW + 1,
+		 "Character discarded, buffer %zu chars = %s\n",
+		 lexer->inbuflen,
+		 gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
 				    (char *)lexer->inbuffer, lexer->inbuflen));
     }
 }
@@ -1499,10 +1520,10 @@ void packet_parse(struct gps_lexer_t *lexer)
 	unsigned int oldstate = lexer->state;
 	if (!nextstate(lexer, c))
 	    continue;
-	gpsd_report(&lexer->errout, LOG_RAW + 2,
-		    "%08ld: character '%c' [%02x], %s -> %s\n",
-		    lexer->char_counter, (isprint(c) ? c : '.'), c,
-		    state_table[oldstate], state_table[lexer->state]);
+	gpsd_log(&lexer->errout, LOG_RAW + 2,
+		 "%08ld: character '%c' [%02x], %s -> %s\n",
+		 lexer->char_counter, (isprint(c) ? c : '.'), c,
+		 state_table[oldstate], state_table[lexer->state]);
 	lexer->char_counter++;
 
 	if (lexer->state == GROUND_STATE) {
@@ -1541,9 +1562,9 @@ void packet_parse(struct gps_lexer_t *lexer)
 				   && csum[1] == toupper((unsigned char) end[2]));
 		}
 		if (!checksum_ok) {
-		    gpsd_report(&lexer->errout, LOG_WARN,
-				"bad checksum in NMEA packet; expected %s.\n",
-				csum);
+		    gpsd_log(&lexer->errout, LOG_WARN,
+			     "bad checksum in NMEA packet; expected %s.\n",
+			     csum);
 		    packet_accept(lexer, BAD_PACKET);
 		    lexer->state = GROUND_STATE;
 		    packet_discard(lexer);
@@ -1594,14 +1615,14 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    for (n = 0; n < lexer->length - 2; n++)
 		a += (unsigned)lexer->inbuffer[n];
 	    b = (unsigned)getleu16(lexer->inbuffer, lexer->length - 2);
-	    gpsd_report(&lexer->errout, LOG_IO,
-			"SuperStarII pkt dump: type %u len %u\n",
-			lexer->inbuffer[1], (unsigned int)lexer->length);
+	    gpsd_log(&lexer->errout, LOG_IO,
+		     "SuperStarII pkt dump: type %u len %u\n",
+		     lexer->inbuffer[1], (unsigned int)lexer->length);
 	    if (a != b) {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "REJECT SuperStarII packet type 0x%02x"
-			    "%zd bad checksum 0x%04x, expecting 0x%04x\n",
-			    lexer->inbuffer[1], lexer->length, a, b);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "REJECT SuperStarII packet type 0x%02x"
+			 "%zd bad checksum 0x%04x, expecting 0x%04x\n",
+			 lexer->inbuffer[1], lexer->length, a, b);
 		packet_accept(lexer, BAD_PACKET);
 		lexer->state = GROUND_STATE;
 	    } else {
@@ -1622,14 +1643,14 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    for (i = 2; i < len - 3; i++)
 		b ^= lexer->inbuffer[i];
 	    if (a == b) {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "Accept OnCore packet @@%c%c len %d\n",
-			    lexer->inbuffer[2], lexer->inbuffer[3], len);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "Accept OnCore packet @@%c%c len %d\n",
+			 lexer->inbuffer[2], lexer->inbuffer[3], len);
 		packet_accept(lexer, ONCORE_PACKET);
 	    } else {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "REJECT OnCore packet @@%c%c len %d\n",
-			    lexer->inbuffer[2], lexer->inbuffer[3], len);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "REJECT OnCore packet @@%c%c len %d\n",
+			 lexer->inbuffer[2], lexer->inbuffer[3], len);
 		packet_accept(lexer, BAD_PACKET);
 		lexer->state = GROUND_STATE;
 	    }
@@ -1650,8 +1671,8 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    if (dlecnt > 2) {
 		dlecnt -= 2;
 		dlecnt /= 2;
-		gpsd_report(&lexer->errout, LOG_RAW,
-			    "Unstuffed %d DLEs\n", dlecnt);
+		gpsd_log(&lexer->errout, LOG_RAW,
+			 "Unstuffed %d DLEs\n", dlecnt);
 		packetlen -= dlecnt;
 	    }
 #endif /* TSIP_ENABLE */
@@ -1701,16 +1722,16 @@ void packet_parse(struct gps_lexer_t *lexer)
 		/*@ +charint */
 		chksum &= 0xff;
 		if (chksum) {
-		    gpsd_report(&lexer->errout, LOG_IO,
-				"Garmin checksum failed: %02x!=0\n", chksum);
+		    gpsd_log(&lexer->errout, LOG_IO,
+			     "Garmin checksum failed: %02x!=0\n", chksum);
 		    goto not_garmin;
 		}
 		packet_accept(lexer, GARMIN_PACKET);
 		packet_discard(lexer);
 		break;
 	      not_garmin:;
-		gpsd_report(&lexer->errout, LOG_RAW + 1,
-			    "Not a Garmin packet\n");
+		gpsd_log(&lexer->errout, LOG_RAW + 1,
+			 "Not a Garmin packet\n");
 #endif /* GARMIN_ENABLE */
 #ifdef TSIP_ENABLE
 		/* check for some common TSIP packet types:
@@ -1760,9 +1781,9 @@ void packet_parse(struct gps_lexer_t *lexer)
 		      (0xbc == pkt_id) ||
 		      (0x38 == pkt_id))
 		    && ((0x41 > pkt_id) || (0x8f < pkt_id))) {
-		    gpsd_report(&lexer->errout, LOG_IO,
-				"Packet ID 0x%02x out of range for TSIP\n",
-				pkt_id);
+		    gpsd_log(&lexer->errout, LOG_IO,
+			     "Packet ID 0x%02x out of range for TSIP\n",
+			     pkt_id);
 		    goto not_tsip;
 		}
                 /* *INDENT-ON* */
@@ -1844,22 +1865,22 @@ void packet_parse(struct gps_lexer_t *lexer)
 		    /* pass */ ;
 		else {
 		    /* pass */ ;
-		    gpsd_report(&lexer->errout, LOG_IO,
-				"TSIP REJECT pkt_id = %#02x, packetlen= %zu\n",
-				pkt_id, packetlen);
+		    gpsd_log(&lexer->errout, LOG_IO,
+			     "TSIP REJECT pkt_id = %#02x, packetlen= %zu\n",
+			     pkt_id, packetlen);
 		    goto not_tsip;
 		}
 #undef TSIP_ID_AND_LENGTH
 		/* Debug */
-		gpsd_report(&lexer->errout, LOG_RAW,
-			    "TSIP pkt_id = %#02x, packetlen= %zu\n",
-			    pkt_id, packetlen);
+		gpsd_log(&lexer->errout, LOG_RAW,
+			 "TSIP pkt_id = %#02x, packetlen= %zu\n",
+			 pkt_id, packetlen);
 		/*@ -charint +ifempty @*/
 		packet_accept(lexer, TSIP_PACKET);
 		packet_discard(lexer);
 		break;
 	      not_tsip:
-		gpsd_report(&lexer->errout, LOG_RAW + 1, "Not a TSIP packet\n");
+		gpsd_log(&lexer->errout, LOG_RAW + 1, "Not a TSIP packet\n");
 		/*
 		 * More attempts to recognize ambiguous TSIP-like
 		 * packet types could go here.
@@ -1878,13 +1899,13 @@ void packet_parse(struct gps_lexer_t *lexer)
 			     lexer->inbufptr - lexer->inbuffer)) {
 		packet_accept(lexer, RTCM3_PACKET);
 	    } else {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "RTCM3 data checksum failure, "
-			    "%0x against %02x %02x %02x\n",
-			    crc24q_hash(lexer->inbuffer,
-					lexer->inbufptr - lexer->inbuffer -
-					3), lexer->inbufptr[-3],
-			    lexer->inbufptr[-2], lexer->inbufptr[-1]);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "RTCM3 data checksum failure, "
+			 "%0x against %02x %02x %02x\n",
+			 crc24q_hash(lexer->inbuffer,
+				     lexer->inbufptr - lexer->inbuffer -
+				     3), lexer->inbufptr[-3],
+			 lexer->inbufptr[-2], lexer->inbufptr[-1]);
 		packet_accept(lexer, BAD_PACKET);
 	    }
 	    packet_discard(lexer);
@@ -1902,9 +1923,9 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    if (len == 0 || sum == getword(5 + len)) {
 		packet_accept(lexer, ZODIAC_PACKET);
 	    } else {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "Zodiac data checksum 0x%hx over length %hd, expecting 0x%hx\n",
-			    sum, len, getword(5 + len));
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "Zodiac data checksum 0x%hx over length %hd, expecting 0x%hx\n",
+			 sum, len, getword(5 + len));
 		packet_accept(lexer, BAD_PACKET);
 		lexer->state = GROUND_STATE;
 	    }
@@ -1919,7 +1940,7 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    unsigned char ck_a = (unsigned char)0;
 	    unsigned char ck_b = (unsigned char)0;
 	    len = lexer->inbufptr - lexer->inbuffer;
-	    gpsd_report(&lexer->errout, LOG_IO, "UBX: len %d\n", len);
+	    gpsd_log(&lexer->errout, LOG_IO, "UBX: len %d\n", len);
 	    for (n = 2; n < (len - 2); n++) {
 		ck_a += lexer->inbuffer[n];
 		ck_b += ck_a;
@@ -1928,15 +1949,15 @@ void packet_parse(struct gps_lexer_t *lexer)
 		ck_b == lexer->inbuffer[len - 1])
 		packet_accept(lexer, UBX_PACKET);
 	    else {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "UBX checksum 0x%02hhx%02hhx over length %d,"
-			    " expecting 0x%02hhx%02hhx (type 0x%02hhx%02hhx)\n",
-			    ck_a,
-			    ck_b,
-			    len,
-			    lexer->inbuffer[len - 2],
-			    lexer->inbuffer[len - 1],
-			    lexer->inbuffer[2], lexer->inbuffer[3]);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "UBX checksum 0x%02hhx%02hhx over length %d,"
+			 " expecting 0x%02hhx%02hhx (type 0x%02hhx%02hhx)\n",
+			 ck_a,
+			 ck_b,
+			 len,
+			 lexer->inbuffer[len - 2],
+			 lexer->inbuffer[len - 1],
+			 lexer->inbuffer[2], lexer->inbuffer[3]);
 		packet_accept(lexer, BAD_PACKET);
 		lexer->state = GROUND_STATE;
 	    }
@@ -1979,9 +2000,9 @@ void packet_parse(struct gps_lexer_t *lexer)
 		goto not_evermore;
 	    crc &= 0xff;
 	    if (crc != checksum) {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "EverMore checksum failed: %02x != %02x\n",
-			    crc, checksum);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "EverMore checksum failed: %02x != %02x\n",
+			 crc, checksum);
 		goto not_evermore;
 	    }
 	    /*@ +charint */
@@ -2021,10 +2042,10 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    if (len == 0 || csum == xsum)
 		packet_accept(lexer, ITALK_PACKET);
 	    else {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "ITALK: checksum failed - "
-			    "type 0x%02x expected 0x%04x got 0x%04x\n",
-			    lexer->inbuffer[4], xsum, csum);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "ITALK: checksum failed - "
+			 "type 0x%02x expected 0x%04x got 0x%04x\n",
+			 lexer->inbuffer[4], xsum, csum);
 		packet_accept(lexer, BAD_PACKET);
 		lexer->state = GROUND_STATE;
 	    }
@@ -2057,9 +2078,9 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    if (cs == 0)
 		packet_accept(lexer, GEOSTAR_PACKET);
 	    else {
-		gpsd_report(&lexer->errout, LOG_IO,
-			    "GeoStar checksum failed 0x%x over length %d\n",
-			    cs, len);
+		gpsd_log(&lexer->errout, LOG_IO,
+			 "GeoStar checksum failed 0x%x over length %d\n",
+			 cs, len);
 		packet_accept(lexer, BAD_PACKET);
 		lexer->state = GROUND_STATE;
 	    }
@@ -2122,28 +2143,28 @@ ssize_t packet_get(int fd, struct gps_lexer_t *lexer)
     /*@ +modobserver @*/
     if (recvd == -1) {
 	if ((errno == EAGAIN) || (errno == EINTR)) {
-	    gpsd_report(&lexer->errout, LOG_RAW + 2, "no bytes ready\n");
+	    gpsd_log(&lexer->errout, LOG_RAW + 2, "no bytes ready\n");
 	    recvd = 0;
 	    /* fall through, input buffer may be nonempty */
 	} else {
-	    gpsd_report(&lexer->errout, LOG_RAW + 2,
-			"errno: %s\n", strerror(errno));
+	    gpsd_log(&lexer->errout, LOG_RAW + 2,
+		     "errno: %s\n", strerror(errno));
 	    return -1;
 	}
     } else {
 	if (lexer->errout.debug >= LOG_RAW+1) {
 	    char scratchbuf[MAX_PACKET_LENGTH*2+1];
-	    gpsd_report(&lexer->errout, LOG_RAW + 1,
-			"Read %zd chars to buffer offset %zd (total %zd): %s\n",
-			recvd, lexer->inbuflen, lexer->inbuflen + recvd,
-			gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
-			    (char *)lexer->inbufptr, (size_t) recvd));
+	    gpsd_log(&lexer->errout, LOG_RAW + 1,
+		     "Read %zd chars to buffer offset %zd (total %zd): %s\n",
+		     recvd, lexer->inbuflen, lexer->inbuflen + recvd,
+		     gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
+				     (char *)lexer->inbufptr, (size_t) recvd));
 	}
 	lexer->inbuflen += recvd;
     }
-    gpsd_report(&lexer->errout, LOG_SPIN,
-		"packet_get() fd %d -> %zd (%d)\n",
-		fd, recvd, errno);
+    gpsd_log(&lexer->errout, LOG_SPIN,
+	     "packet_get() fd %d -> %zd (%d)\n",
+	     fd, recvd, errno);
 
     /*
      * Bail out, indicating no more input, only if we just received
