@@ -4,8 +4,6 @@
  * If you are not good at threads do not touch this file!
  * For example: errno is thread safe; strerror() is not.
  *
- * FIXME: find a portable and thread safe replacement for strerror().
- *
  * It helps to know that there are two PPS measurement methods in
  * play.  One is defined by RFC2783 and typically implemented in the
  * kernel.  It is available on FreeBSD, Linux, and NetBSD.  In gpsd it
@@ -48,6 +46,9 @@
  */
 
 #include <string.h>
+#include <stdio.h>
+#include <stdbool.h>
+#include <limits.h>
 #include <errno.h>
 #include <pthread.h>
 #include <math.h>
@@ -56,16 +57,16 @@
 #include <unistd.h>
 #endif /* S_SPLINT_S */
 
-#include "gpsd.h"
+#include "gpsd_config.h"
+#include "timespec_str.h"
+#include "ppsthread.h"
+#include "compiler.h"	/* required for erno thread-safety */
 
 #ifdef PPS_ENABLE
 #if defined(HAVE_SYS_TIMEPPS_H)
 #include <fcntl.h>	/* needed for open() and friends */
 #endif /* defined(HAVE_SYS_TIMEPPS_H) */
 
-#define PPS_MAX_OFFSET	100000	/* microseconds the PPS can 'pull' */
-#define PUT_MAX_OFFSET	1000000	/* microseconds for lost lock */
-
 /*
  * Warning: This is a potential portability problem.
  * It's needed so that TIOCMIWAIT will be defined and the plain PPS
@@ -83,44 +84,76 @@
 #include <glob.h>
 #endif
 
-static pthread_mutex_t ppslast_mutex;
-
-void pps_early_init( struct gps_context_t * context ) {
-    int err;
-
-    /*@ -unrecog  (splint has no pthread declarations as yet) @*/
-    /*@ -nullpass @*/
-    err = pthread_mutex_init(&ppslast_mutex, NULL);
-    /*@ +nullpass@ */
-    /*@ +unrecog @*/
-    if ( 0 != err ) {
-	gpsd_report(&context->errout, LOG_ERROR,
-		"PPS: pthread_mutex_init() : %s\n",
-		strerror(errno));
+/* normalize a timespec
+ *
+ * three cases to note
+ * if tv_sec is positve, then tv_nsec must be positive
+ * if tv_sec is negative, then tv_nsec must be negative
+ * if tv_sec is zero, then tv_nsec may be positive or negative.
+ *
+ * this only handles the case where two normalized timespecs
+ * are added or subracted.  (e.g. only a one needs to be borrowed/carried
+ */
+/*@-type -noeffect@*/ /* splint is confused about struct timespec */
+/*@unused@*/static inline void TS_NORM( struct timespec *ts)
+{
+    if ( (  1 <= ts->tv_sec ) ||
+         ( (0 == ts->tv_sec ) && (0 <= ts->tv_nsec ) ) ) {
+        /* result is positive */
+	if ( 1000000000 <= ts->tv_nsec ) {
+            /* borrow from tv_sec */
+	    ts->tv_nsec -= 1000000000;
+	    ts->tv_sec++;
+	} else if ( 0 > (ts)->tv_nsec ) {
+            /* carry to tv_sec */
+	    ts->tv_nsec += 1000000000;
+	    ts->tv_sec--;
+	}
+    }  else {
+        /* result is negative */
+	if ( -1000000000 >= ts->tv_nsec ) {
+            /* carry to tv_sec */
+	    ts->tv_nsec += 1000000000;
+	    ts->tv_sec--;
+	} else if ( 0 < ts->tv_nsec ) {
+            /* borrow from tv_sec */
+	    ts->tv_nsec -= 1000000000;
+	    ts->tv_sec++;
+	}
     }
 }
+/*@+type +noeffect@*/
+
+/* subtract two timespec */
+#define TS_SUB(r, ts1, ts2) \
+    do { \
+	(r)->tv_sec = (ts1)->tv_sec - (ts2)->tv_sec; \
+	(r)->tv_nsec = (ts1)->tv_nsec - (ts2)->tv_nsec; \
+        TS_NORM( r ); \
+    } while (0)
+
+
+/*@i1@*/static pthread_mutex_t ppslast_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 #if defined(HAVE_SYS_TIMEPPS_H)
 /*@-compdestroy -nullpass -unrecog@*/
-static int init_kernel_pps(struct gps_device_t *session)
+static int init_kernel_pps(volatile struct pps_thread_t *pps_thread)
 /* return handle for kernel pps, or -1; requires root privileges */
 {
 #ifndef S_SPLINT_S
     pps_params_t pp;
 #endif /* S_SPLINT_S */
     int ret;
-#ifdef linux
+#ifdef __linux__
     /* These variables are only needed by Linux to find /dev/ppsN. */
     int ldisc = 18;   /* the PPS line discipline */
     glob_t globbuf;
-    size_t i;             /* to match type of globbuf.gl_pathc */
-    char pps_num = '\0';  /* /dev/pps[pps_num] is our device */
-    char path[GPS_PATH_MAX] = "";
+    char path[PATH_MAX] = "";
 #endif
 
-    session->kernelpps_handle = -1;
-    if ( isatty(session->gpsdata.gps_fd) == 0 ) {
-	gpsd_report(&session->context->errout, LOG_INF, "KPPS gps_fd not a tty\n");
+    pps_thread->kernelpps_handle = -1;
+    if ( isatty(pps_thread->devicefd) == 0 ) {
+	pps_thread->log_hook(pps_thread, THREAD_INF, "KPPS gps_fd not a tty\n");
     	return -1;
     }
 
@@ -129,114 +162,129 @@ static int init_kernel_pps(struct gps_device_t *session)
      * to use for RFC2783 calls.
      */
     ret = -1;
-#ifdef linux
+#ifdef __linux__
     /*
-     * On Linux, one must make calls to associate a serial port with a
-     * /dev/ppsN device and then grovel in system data to determine
-     * the association.
+     * Some Linuxes, like the RasbPi's, have PPS devices preexisting.
+     * Allow user to pass in an explicit PPS device path.
      */
-    /*@+ignoresigns@*/
-    /* Attach the line PPS discipline, so no need to ldattach */
-    /* This activates the magic /dev/pps0 device */
-    /* Note: this ioctl() requires root */
-    if ( 0 > ioctl(session->gpsdata.gps_fd, TIOCSETD, &ldisc)) {
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "KPPS cannot set PPS line discipline on %s : %s\n",
-		    session->gpsdata.dev.path, strerror(errno));
-    	return -1;
-    }
-    /*@-ignoresigns@*/
-
-    /* uh, oh, magic file names!, RFC2783 neglects to specify how
-     * to associate the serial device and pps device names */
-    /* need to look in /sys/devices/virtual/pps/pps?/path
-     * (/sys/class/pps/pps?/path is just a link to that)
-     * to find the /dev/pps? that matches our serial port.
-     * this code fails if there are more then 10 pps devices.
-     *
-     * yes, this could be done with libsysfs, but trying to keep the
-     * number of required libs small, and libsysfs would still be linux only */
-    memset( (void *)&globbuf, 0, sizeof(globbuf));
-    (void)glob("/sys/devices/virtual/pps/pps?/path", 0, NULL, &globbuf);
-
-    memset( (void *)&path, 0, sizeof(path));
-    for ( i = 0; i < globbuf.gl_pathc; i++ ) {
-        int fd = open(globbuf.gl_pathv[i], O_RDONLY);
-	if ( 0 <= fd ) {
-	    ssize_t r = read( fd, path, sizeof(path) -1);
-	    if ( 0 < r ) {
-		path[r - 1] = '\0'; /* remove trailing \x0a */
-	    }
-	    (void)close(fd);
-	}
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "KPPS checking %s, %s\n",
-		    globbuf.gl_pathv[i], path);
-	if ( 0 == strncmp( path, session->gpsdata.dev.path, sizeof(path))) {
-	    /* this is the pps we are looking for */
-	    /* FIXME, now build the proper pps device path */
-	    pps_num = globbuf.gl_pathv[i][28];
-	    break;
+    if (strncmp(pps_thread->devicename, "/dev/pps", 8) == 0)
+	strlcpy(path, pps_thread->devicename, sizeof(path));
+    else {
+	char pps_num = '\0';  /* /dev/pps[pps_num] is our device */
+	size_t i;             /* to match type of globbuf.gl_pathc */
+	/*
+	 * Otherwise one must make calls to associate a serial port with a
+	 * /dev/ppsN device and then grovel in system data to determine
+	 * the association.
+	 */
+	/*@+ignoresigns@*/
+	/* Attach the line PPS discipline, so no need to ldattach */
+	/* This activates the magic /dev/pps0 device */
+	/* Note: this ioctl() requires root */
+	if ( 0 > ioctl(pps_thread->devicefd, TIOCSETD, &ldisc)) {
+	    char errbuf[BUFSIZ] = "unknown error";
+	    strerror_r(errno, errbuf, sizeof(errbuf));
+	    pps_thread->log_hook(pps_thread, THREAD_INF,
+				 "KPPS cannot set PPS line discipline on %s : %s\n",
+				 pps_thread->devicename, errbuf);
+	    return -1;
 	}
+	/*@-ignoresigns@*/
+
+	/* uh, oh, magic file names!, RFC2783 neglects to specify how
+	 * to associate the serial device and pps device names */
+	/* need to look in /sys/devices/virtual/pps/pps?/path
+	 * (/sys/class/pps/pps?/path is just a link to that)
+	 * to find the /dev/pps? that matches our serial port.
+	 * this code fails if there are more then 10 pps devices.
+	 *
+	 * yes, this could be done with libsysfs, but trying to keep the
+	 * number of required libs small, and libsysfs would still be linux only */
+	memset( (void *)&globbuf, 0, sizeof(globbuf));
+	(void)glob("/sys/devices/virtual/pps/pps?/path", 0, NULL, &globbuf);
+
 	memset( (void *)&path, 0, sizeof(path));
-    }
-    /* done with blob, clear it */
-    globfree(&globbuf);
+	for ( i = 0; i < globbuf.gl_pathc; i++ ) {
+	    int fd = open(globbuf.gl_pathv[i], O_RDONLY);
+	    if ( 0 <= fd ) {
+		ssize_t r = read( fd, path, sizeof(path) -1);
+		if ( 0 < r ) {
+		    path[r - 1] = '\0'; /* remove trailing \x0a */
+		}
+		(void)close(fd);
+	    }
+	    pps_thread->log_hook(pps_thread, THREAD_INF,
+				 "KPPS checking %s, %s\n",
+				 globbuf.gl_pathv[i], path);
+	    if ( 0 == strncmp( path, pps_thread->devicename, sizeof(path))) {
+		/* this is the pps we are looking for */
+		/* FIXME, now build the proper pps device path */
+		pps_num = globbuf.gl_pathv[i][28];
+		break;
+	    }
+	    memset( (void *)&path, 0, sizeof(path));
+	}
+	/* done with blob, clear it */
+	globfree(&globbuf);
 
-    if ( 0 == (int)pps_num ) {
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "KPPS device not found.\n");
-    	return -1;
+	if ( 0 == (int)pps_num ) {
+	    pps_thread->log_hook(pps_thread, THREAD_INF,
+				 "KPPS device not found.\n");
+	    return -1;
+	}
+	/* construct the magic device path */
+	(void)snprintf(path, sizeof(path), "/dev/pps%c", pps_num);
     }
-    /* contruct the magic device path */
-    (void)snprintf(path, sizeof(path), "/dev/pps%c", pps_num);
 
     /* root privs are required for this device open */
     if ( 0 != getuid() ) {
-	gpsd_report(&session->context->errout, LOG_INF,
+	pps_thread->log_hook(pps_thread, THREAD_INF,
 		    "KPPS only works as root \n");
     	return -1;
     }
     ret = open(path, O_RDWR);
     if ( 0 > ret ) {
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "KPPS cannot open %s: %s\n", path, strerror(errno));
+	char errbuf[BUFSIZ] = "unknown error";
+	(void)strerror_r(errno, errbuf, sizeof(errbuf));
+	pps_thread->log_hook(pps_thread, THREAD_INF,
+		    "KPPS cannot open %s: %s\n", path, errbuf);
     	return -1;
     }
-#else /* not linux */
+#else /* not __linux__ */
     /*
      * On BSDs that support RFC2783, one uses the API calls on serial
      * port file descriptor.
      */
     // cppcheck-suppress redundantAssignment
-    ret  = session->gpsdata.gps_fd;
+    ret  = pps_thread->devicefd;
 #endif
     /* assert(ret >= 0); */
-    gpsd_report(&session->context->errout, LOG_INF,
+    pps_thread->log_hook(pps_thread, THREAD_INF,
 		"KPPS RFC2783 fd is %d\n",
 		ret);
 
     /* RFC 2783 implies the time_pps_setcap() needs priviledges *
      * keep root a tad longer just in case */
-    if ( 0 > time_pps_create(ret, &session->kernelpps_handle )) {
-	gpsd_report(&session->context->errout, LOG_INF,
+    if ( 0 > time_pps_create(ret, (pps_handle_t *)&pps_thread->kernelpps_handle )) {
+	char errbuf[BUFSIZ] = "unknown error";
+	(void)strerror_r(errno, errbuf, (int)sizeof(errbuf));
+	pps_thread->log_hook(pps_thread, THREAD_INF,
 		    "KPPS time_pps_create(%d) failed: %s\n",
-		    ret, strerror(errno));
+		    ret, errbuf);
     	return -1;
     } else {
 #ifndef S_SPLINT_S
     	/* have kernel PPS handle */
         int caps;
 	/* get features  supported */
-        if ( 0 > time_pps_getcap(session->kernelpps_handle, &caps)) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
+        if ( 0 > time_pps_getcap(pps_thread->kernelpps_handle, &caps)) {
+	    pps_thread->log_hook(pps_thread, THREAD_ERROR,
 			"KPPS time_pps_getcap() failed\n");
         } else {
-	    gpsd_report(&session->context->errout,
-			LOG_INF, "KPPS caps %0x\n", caps);
+	    pps_thread->log_hook(pps_thread, THREAD_INF, "KPPS caps %0x\n", caps);
         }
 
-#ifdef linux
+#ifdef __linux__
         /* linux 2.6.34 can not PPS_ECHOASSERT | PPS_ECHOCLEAR */
         memset( (void *)&pp, 0, sizeof(pps_params_t));
         pp.mode = PPS_CAPTUREBOTH;
@@ -248,10 +296,12 @@ static int init_kernel_pps(struct gps_device_t *session)
 #endif
 #endif /* S_SPLINT_S */
 
-        if ( 0 > time_pps_setparams(session->kernelpps_handle, &pp)) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-		"KPPS time_pps_setparams() failed: %s\n", strerror(errno));
-	    time_pps_destroy(session->kernelpps_handle);
+        if ( 0 > time_pps_setparams(pps_thread->kernelpps_handle, &pp)) {
+	    char errbuf[BUFSIZ] = "unknown error";
+	    (void)strerror_r(errno, errbuf, (int)sizeof(errbuf));
+	    pps_thread->log_hook(pps_thread, THREAD_ERROR,
+		"KPPS time_pps_setparams() failed: %s\n", errbuf);
+	    time_pps_destroy(pps_thread->kernelpps_handle);
 	    return -1;
         }
     }
@@ -264,19 +314,15 @@ static int init_kernel_pps(struct gps_device_t *session)
 static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 {
     char ts_str1[TIMESPEC_LEN], ts_str2[TIMESPEC_LEN];
-    struct gps_device_t *session = (struct gps_device_t *)arg;
-    double last_fixtime_real = 0; 
-    /* the system clock ime, to the nSec, when the last fix received */
+    volatile struct pps_thread_t *thread_context = (struct pps_thread_t *)arg;
+    /* the system clock time, to the nSec, when the last fix received */
     /* using a double would cause loss of precision */
-    struct timespec last_fixtime_clock = {0, 0};
-#ifndef HAVE_CLOCK_GETTIME
-    struct timeval  clock_tv = {0, 0};
-#endif /* HAVE_CLOCK_GETTIME */
+    volatile struct timedelta_t last_fixtime = {{0, 0}, {0, 0}};
     struct timespec clock_ts = {0, 0};
     time_t last_second_used = 0;
 #if defined(TIOCMIWAIT)
     int cycle, duration; 
-    /* state is the last state of the tty control ssignals */
+    /* state is the last state of the tty control signals */
     int state = 0, unchanged = 0;
     /* state_last is previous state */
     int state_last = 0;
@@ -308,12 +354,12 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
      * configuration switch. 
      *
      * Once we have the latest edge we compare it to the last edge which we
-     * stored.  If the edge passes sanity checks we use it to send to
-     * ntpshm and chrony_send
+     * stored.  If the edge passes sanity checks we pass is out through
+     * the call context.
      */
 
-    while (session->thread_report_hook != NULL 
-           || session->context->pps_hook != NULL) {
+    while (thread_context->report_hook != NULL
+           || thread_context->pps_hook != NULL) {
 	bool ok = false;
 #ifndef S_SPLINT_S
 #if defined(HAVE_SYS_TIMEPPS_H)
@@ -325,11 +371,13 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 
 #if defined(TIOCMIWAIT)
         /* we are lucky to have TIOCMIWAIT, so wait for next edge */
-#define PPS_LINE_TIOC (TIOCM_CD|TIOCM_CAR|TIOCM_RI|TIOCM_CTS)
-        if (ioctl(session->gpsdata.gps_fd, TIOCMIWAIT, PPS_LINE_TIOC) != 0) {
-	    gpsd_report(&session->context->errout, LOG_WARN,
+#define PPS_LINE_TIOC (TIOCM_CD|TIOCM_RI|TIOCM_CTS)
+        if (ioctl(thread_context->devicefd, TIOCMIWAIT, PPS_LINE_TIOC) != 0) {
+	    char errbuf[BUFSIZ] = "unknown error";
+	    (void)strerror_r(errno, errbuf, sizeof(errbuf));
+	    thread_context->log_hook(thread_context, THREAD_WARN,
 			"PPS ioctl(TIOCMIWAIT) on %s failed: %d %.40s\n",
-			session->gpsdata.dev.path, errno, strerror(errno));
+			thread_context->devicename, errno, errbuf);
 	    break;
 	}
         /*
@@ -341,66 +389,57 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	/*@ -unrecog  (splint has no pthread declarations as yet) @*/
 	pthread_err = pthread_mutex_lock(&ppslast_mutex);
 	if ( 0 != pthread_err ) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-		    "PPS: pthread_mutex_lock() : %s\n",
-		    strerror(errno));
+	    char errbuf[BUFSIZ] = "unknown error";
+	    (void)strerror_r(errno, errbuf, sizeof(errbuf));
+	    thread_context->log_hook(thread_context, THREAD_ERROR,
+		    "PPS: pthread_mutex_lock() : %s\n", errbuf);
 	}
 	/*@ +unrecog @*/
-	last_fixtime_real = session->last_fixtime.real;
-	last_fixtime_clock = session->last_fixtime.clock;
+	last_fixtime = thread_context->fixin;
 	/*@ -unrecog (splint has no pthread declarations as yet) @*/
 	pthread_err = pthread_mutex_unlock(&ppslast_mutex);
 	if ( 0 != pthread_err ) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-		    "PPS: pthread_mutex_unlock() : %s\n",
-		    strerror(errno));
+	    char errbuf[BUFSIZ] = "unknown error";
+	    (void)strerror_r(errno, errbuf, sizeof(errbuf));
+	    thread_context->log_hook(thread_context, THREAD_ERROR,
+			"PPS: pthread_mutex_unlock() : %s\n", errbuf);
 	}
 	/*@ +unrecog @*/
 
 /*@-noeffect@*/
         /* get the time after we just woke up */
-#ifdef HAVE_CLOCK_GETTIME
-	/* using  clock_gettime() here, that is nSec,
-	 * not uSec like gettimeofday */
 	if ( 0 > clock_gettime(CLOCK_REALTIME, &clock_ts) ) {
 	    /* uh, oh, can not get time! */
-	    gpsd_report(&session->context->errout, LOG_ERROR,
+	    thread_context->log_hook(thread_context, THREAD_ERROR,
 			"PPS clock_gettime() failed\n");
 	    break;
 	}
-#else
-	if ( 0 > gettimeofday(&clock_tv, NULL) ) {
-	    /* uh, oh, can not get time! */
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"PPS gettimeofday() failed\n");
-	    break;
-	}
-	TVTOTS( &clock_ts, &clock_tv);
-#endif /* HAVE_CLOCK_GETTIME */
 /*@+noeffect@*/
      
         /* got the edge, got the time just after the edge, now quickly
          * get the edge state */
 	/*@ +ignoresigns */
-	if (ioctl(session->gpsdata.gps_fd, TIOCMGET, &state) != 0) {
-	    gpsd_report(&session->context->errout, LOG_ERROR,
+	if (ioctl(thread_context->devicefd, TIOCMGET, &state) != 0) {
+	    thread_context->log_hook(thread_context, THREAD_ERROR,
 			"PPS ioctl(TIOCMGET) on %s failed\n",
-			session->gpsdata.dev.path);
+			thread_context->devicename);
 	    break;
 	}
 	/*@ -ignoresigns */
         /* end of time critical section */
-	gpsd_report(&session->context->errout, LOG_PROG,
+	thread_context->log_hook(thread_context, THREAD_PROG,
 		    "PPS ioctl(TIOCMIWAIT) on %s succeeded\n",
-		    session->gpsdata.dev.path);
+		    thread_context->devicename);
 
 	/*
-	 * If there was no valid time from the GPS when the PPS event was
-	 * asserted, we can do nothing further.  It will be strange if
-	 * this ever actually happens, since we expect PPS to be asserted
-	 * only after a valid fix - which should yield time.
+	 * If there has not yet bben any valid in-band time stashed
+	 * from the GPS when the PPS event was asserted, we can do
+	 * nothing further.  Some GPSes like Garmin always send a PPS,
+	 * valid or not.  Other GPSes like some uBlox may only send
+	 * PPS when time is valid.  It is common to get PPS, and no
+	 * fixtime, while autobauding.
 	 */
-        if (isnan(last_fixtime_real))
+        if (last_fixtime.real.tv_sec == 0)
 	    continue;
 
 	/* mask for monitored lines */
@@ -413,7 +452,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	ok = false;  
 	log = NULL;  
 #if defined(HAVE_SYS_TIMEPPS_H) && !defined(S_SPLINT_S)
-        if ( 0 <= session->kernelpps_handle ) {
+        if ( 0 <= thread_context->kernelpps_handle ) {
 	    struct timespec kernelpps_tv;
 	    /* on a quad core 2.4GHz Xeon using KPPS timestamp instead of plain 
              * PPS timestamp removes about 20uS of latency, and about +/-5uS 
@@ -438,9 +477,9 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    kernelpps_tv.tv_sec = 1;
 	    kernelpps_tv.tv_nsec = 0;
 #endif
-	    if ( 0 > time_pps_fetch(session->kernelpps_handle, PPS_TSFMT_TSPEC
+	    if ( 0 > time_pps_fetch(thread_context->kernelpps_handle, PPS_TSFMT_TSPEC
 	        , &pi, &kernelpps_tv)) {
-		gpsd_report(&session->context->errout, LOG_ERROR,
+		thread_context->log_hook(thread_context, THREAD_ERROR,
 			    "KPPS kernel PPS failed\n");
 	    } else {
 		// find the last edge
@@ -466,14 +505,14 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 		 */
 		timespec_str( &pi.assert_timestamp, ts_str1, sizeof(ts_str1) );
 		timespec_str( &pi.clear_timestamp, ts_str2, sizeof(ts_str2) );
-		gpsd_report(&session->context->errout, LOG_PROG,
+		thread_context->log_hook(thread_context, THREAD_PROG,
 			    "KPPS assert %s, sequence: %ld - "
 			    "clear  %s, sequence: %ld\n",
 			    ts_str1,
 			    (unsigned long) pi.assert_sequence,
 			    ts_str2,
 			    (unsigned long) pi.clear_sequence);
-		gpsd_report(&session->context->errout, LOG_PROG,
+		thread_context->log_hook(thread_context, THREAD_PROG,
 			    "KPPS data: using %s\n",
 			    edge_kpps ? "assert" : "clear");
 
@@ -482,7 +521,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	        cycle_kpps = timespec_diff_ns(ts_kpps, pulse_kpps[edge_kpps])/1000;
 	        duration_kpps = timespec_diff_ns(ts_kpps, pulse_kpps[(int)(edge_kpps == 0)])/1000;
 		timespec_str( &ts_kpps, ts_str1, sizeof(ts_str1) );
-	        gpsd_report(&session->context->errout, LOG_PROG,
+	        thread_context->log_hook(thread_context, THREAD_PROG,
 		    "KPPS cycle: %7d uSec, duration: %7d uSec @ %s\n",
 		    cycle_kpps, duration_kpps, ts_str1);
 		pulse_kpps[edge_kpps] = ts_kpps;
@@ -505,27 +544,27 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    if (999000 < cycle && 1001000 > cycle) {
 		duration = 0;
 		unchanged = 0;
-		gpsd_report(&session->context->errout, LOG_RAW,
+		thread_context->log_hook(thread_context, THREAD_RAW,
 			    "PPS pps-detect on %s invisible pulse\n",
-			    session->gpsdata.dev.path);
+			    thread_context->devicename);
 	    } else if (++unchanged == 10) {
                 /* not really unchanged, just out of bounds */
 		unchanged = 1;
-		gpsd_report(&session->context->errout, LOG_WARN,
+		thread_context->log_hook(thread_context, THREAD_WARN,
 			    "PPS TIOCMIWAIT returns unchanged state, ppsmonitor sleeps 10\n");
 		(void)sleep(10);
 	    }
 	} else {
-	    gpsd_report(&session->context->errout, LOG_RAW,
+	    thread_context->log_hook(thread_context, THREAD_RAW,
 			"PPS pps-detect on %s changed to %d\n",
-			session->gpsdata.dev.path, state);
+			thread_context->devicename, state);
 	    unchanged = 0;
 	}
 	state_last = state;
         /* save this edge so we know next cycle time */
 	pulse[edge] = clock_ts;
 	timespec_str( &clock_ts, ts_str1, sizeof(ts_str1) );
-	gpsd_report(&session->context->errout, LOG_PROG,
+	thread_context->log_hook(thread_context, THREAD_PROG,
 		    "PPS edge: %d, cycle: %7d uSec, duration: %7d uSec @ %s\n",
 		    edge, cycle, duration, ts_str1);
 	if (unchanged) {
@@ -617,7 +656,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    log = "Too long for 0.5Hz\n";
 	}
 #endif /* TIOCMIWAIT */
-	if ( ok && last_second_used >= last_fixtime_real ) {
+	if ( ok && last_second_used >= last_fixtime.real.tv_sec ) {
 		/* uh, oh, this second already handled */
 		ok = 0;
 		log = "this second already handled\n";
@@ -635,13 +674,13 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    char *log1 = NULL;
 	    /* ppstimes.real is the time we think the pulse represents  */
 	    struct timedelta_t ppstimes;
-	    gpsd_report(&session->context->errout, LOG_RAW,
+	    thread_context->log_hook(thread_context, THREAD_RAW,
 			"PPS edge accepted %.100s", log);
 #ifndef S_SPLINT_S
 #if defined(HAVE_SYS_TIMEPPS_H)
-            if ( 0 <= session->kernelpps_handle && ok_kpps) {
+            if ( 0 <= thread_context->kernelpps_handle && ok_kpps) {
 		/* use KPPS time */
-		gpsd_report(&session->context->errout, LOG_RAW,
+		thread_context->log_hook(thread_context, THREAD_RAW,
 			    "KPPS using edge %d", edge_kpps );
 		/* pick the right edge */
 		if ( edge_kpps ) {
@@ -666,7 +705,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
              */
 
 	    /*@+relaxtypes@*/
-	    ppstimes.real.tv_sec = (time_t)trunc(last_fixtime_real) + 1;
+	    ppstimes.real.tv_sec = (time_t)last_fixtime.real.tv_sec + 1;
 	    ppstimes.real.tv_nsec = 0;  /* need to be fixed for 5Hz */
 	    ppstimes.clock = clock_ts;
 	    /*@-relaxtypes@*/
@@ -675,55 +714,57 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	     * GPS serial input then use that */
 	    /*@-compdef@*/
 	    TS_SUB( &offset, &ppstimes.real, &ppstimes.clock);
-	    TS_SUB( &delay, &ppstimes.clock, &last_fixtime_clock);
+	    TS_SUB( &delay, &ppstimes.clock, &last_fixtime.clock);
 	    timespec_str( &delay, delay_str, sizeof(delay_str) );
 	    /*@+compdef@*/
 
 	    if ( 0> delay.tv_sec || 0 > delay.tv_nsec ) {
-		gpsd_report(&session->context->errout, LOG_RAW,
+		thread_context->log_hook(thread_context, THREAD_RAW,
 			    "PPS: system clock went backwards: %.20s\n",
 			    delay_str);
 		log1 = "system clock went backwards";
 	    } else if ( ( 2 < delay.tv_sec) 
 	      || ( 1 == delay.tv_sec && 100000000 > delay.tv_nsec ) ) {
                 /* system clock could be slewing so allow 1.1 sec delay */
-		gpsd_report(&session->context->errout, LOG_RAW,
+		thread_context->log_hook(thread_context, THREAD_RAW,
 			    "PPS: no current GPS seconds: %.20s\n",
 			    delay_str);
 		log1 = "timestamp out of range";
 	    } else {
 		/*@-compdef@*/
-		last_second_used = last_fixtime_real;
-		if (session->thread_report_hook != NULL) 
-		    log1 = session->thread_report_hook(session, &ppstimes);
+		last_second_used = last_fixtime.real.tv_sec;
+		if (thread_context->report_hook != NULL) 
+		    log1 = thread_context->report_hook(thread_context, &ppstimes);
 		else
 		    log1 = "no report hook";
-		if (session->context->pps_hook != NULL)
-		    session->context->pps_hook(session, &ppstimes);
+		if (thread_context->pps_hook != NULL)
+		    thread_context->pps_hook(thread_context, &ppstimes);
 		/*@ -unrecog  (splint has no pthread declarations as yet) @*/
 		pthread_err = pthread_mutex_lock(&ppslast_mutex);
                 if ( 0 != pthread_err ) {
-		    gpsd_report(&session->context->errout, LOG_ERROR,
-			    "PPS: pthread_mutex_lock() : %s\n",
-			    strerror(errno));
+		    char errbuf[BUFSIZ] = "unknown error";
+		    (void)strerror_r(errno, errbuf, sizeof(errbuf));
+		    thread_context->log_hook(thread_context, THREAD_ERROR,
+			    "PPS: pthread_mutex_lock() : %s\n", errbuf);
 		}
 		/*@ +unrecog @*/
 		/*@-type@*/ /* splint is confused about struct timespec */
-		session->ppslast = ppstimes;
+		thread_context->ppsout_last = ppstimes;
 		/*@+type@*/
-		session->ppscount++;
+		thread_context->ppsout_count++;
 		/*@ -unrecog (splint has no pthread declarations as yet) @*/
 		pthread_err = pthread_mutex_unlock(&ppslast_mutex);
                 if ( 0 != pthread_err ) {
-		    gpsd_report(&session->context->errout, LOG_ERROR,
-			    "PPS: pthread_mutex_unlock() : %s\n",
-			    strerror(errno));
+		    char errbuf[BUFSIZ] = "unknown error";
+		    (void)strerror_r(errno, errbuf, (int)sizeof(errbuf));
+		    thread_context->log_hook(thread_context, THREAD_ERROR,
+			    "PPS: pthread_mutex_unlock() : %s\n", errbuf);
 		}
 		/*@ +unrecog @*/
 		/*@-type@*/ /* splint is confused about struct timespec */
 		timespec_str( &ppstimes.clock, ts_str1, sizeof(ts_str1) );
 		timespec_str( &ppstimes.real, ts_str2, sizeof(ts_str2) );
-		gpsd_report(&session->context->errout, LOG_INF,
+		thread_context->log_hook(thread_context, THREAD_INF,
 			    "PPS hooks called with %.20s clock: %s real: %s\n",
 			    log1, ts_str1, ts_str2);
 		/*@+type@*/
@@ -733,26 +774,26 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    /*@-type@*/ /* splint is confused about struct timespec */
 	    timespec_str( &clock_ts, ts_str1, sizeof(ts_str1) );
 	    timespec_str( &offset, offset_str, sizeof(offset_str) );
-	    gpsd_report(&session->context->errout, LOG_PROG,
+	    thread_context->log_hook(thread_context, THREAD_PROG,
 		    "PPS edge %.20s @ %s offset %.20s\n",
 		    log1, ts_str1, offset_str);
 	    /*@+type@*/
 	    /*@+compdef@*/
 	} else {
-	    gpsd_report(&session->context->errout, LOG_RAW,
+	    thread_context->log_hook(thread_context, THREAD_RAW,
 			"PPS edge rejected %.100s", log);
 	}
     }
 #if defined(HAVE_SYS_TIMEPPS_H)
-    if (session->kernelpps_handle > 0) {
-	gpsd_report(&session->context->errout, LOG_PROG, 
+    if (thread_context->kernelpps_handle > 0) {
+	thread_context->log_hook(thread_context, THREAD_PROG, 
             "PPS descriptor cleaned up\n");
-	(void)time_pps_destroy(session->kernelpps_handle);
+	(void)time_pps_destroy(thread_context->kernelpps_handle);
     }
 #endif
-    if (session->thread_wrap_hook != NULL)
-	session->thread_wrap_hook(session);
-    gpsd_report(&session->context->errout, LOG_PROG, 
+    if (thread_context->wrap_hook != NULL)
+	thread_context->wrap_hook(thread_context);
+    thread_context->log_hook(thread_context, THREAD_PROG, 
          "PPS gpsd_ppsmonitor exited.\n");
     return NULL;
 }
@@ -762,60 +803,62 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
  * Entry points begin here.
  */
 
-void pps_thread_activate(struct gps_device_t *session)
+void pps_thread_activate(volatile struct pps_thread_t *pps_thread)
 /* activate a thread to watch the device's PPS transitions */
 {
     int retval;
     pthread_t pt;
 #if defined(HAVE_SYS_TIMEPPS_H)
     /* some operations in init_kernel_pps() require root privs */
-    (void)init_kernel_pps( session );
-    if ( 0 <= session->kernelpps_handle ) {
-	gpsd_report(&session->context->errout, LOG_WARN,
+    (void)init_kernel_pps(pps_thread);
+    if ( 0 <= pps_thread->kernelpps_handle ) {
+	pps_thread->log_hook(pps_thread, THREAD_WARN,
 		    "KPPS kernel PPS will be used\n");
     }
 #endif
     /*@-compdef -nullpass@*/
-    retval = pthread_create(&pt, NULL, gpsd_ppsmonitor, (void *)session);
+    retval = pthread_create(&pt, NULL, gpsd_ppsmonitor, (void *)pps_thread);
     /*@+compdef +nullpass@*/
-    gpsd_report(&session->context->errout, LOG_PROG, "PPS thread %s\n",
+    pps_thread->log_hook(pps_thread, THREAD_PROG, "PPS thread %s\n",
 		(retval==0) ? "launched" : "FAILED");
 }
 
-void pps_thread_deactivate(struct gps_device_t *session)
+void pps_thread_deactivate(volatile struct pps_thread_t *pps_thread)
 /* cleanly terminate PPS thread */
 {
     /*@-nullstate -mustfreeonly@*/
-    session->thread_report_hook = NULL;
-    session->context->pps_hook = NULL;
+    pps_thread->report_hook = NULL;
+    pps_thread->pps_hook = NULL;
     /*@+nullstate +mustfreeonly@*/
 }
 
-void pps_thread_stash_fixtime(struct gps_device_t *session, 
-		   timestamp_t realtime, struct timespec clocktime)
+void pps_thread_fixin(volatile struct pps_thread_t *pps_thread, 
+			      volatile struct timedelta_t *fixin)
 /* thread-safe update of last fix time - only way we pass data in */
 {
     /*@ -unrecog  (splint has no pthread declarations as yet) @*/
     int pthread_err = pthread_mutex_lock(&ppslast_mutex);
     if ( 0 != pthread_err ) {
-	gpsd_report(&session->context->errout, LOG_ERROR,
-		"PPS: pthread_mutex_lock() : %s\n",
-		strerror(errno));
+	char errbuf[BUFSIZ] = "unknown error";
+	(void)strerror_r(errno, errbuf, (int)sizeof(errbuf));
+	pps_thread->log_hook(pps_thread, THREAD_ERROR,
+		"PPS: pthread_mutex_lock() : %s\n", errbuf);
     }
     /*@ +unrecog @*/
-    session->last_fixtime.real = realtime;
-    session->last_fixtime.clock = clocktime;
+    pps_thread->fixin = *fixin;
     /*@ -unrecog (splint has no pthread declarations as yet) @*/
     pthread_err = pthread_mutex_unlock(&ppslast_mutex);
     if ( 0 != pthread_err ) {
-	gpsd_report(&session->context->errout, LOG_ERROR,
-		"PPS: pthread_mutex_unlock() : %s\n",
-		strerror(errno));
+	char errbuf[BUFSIZ] = "unknown error";
+	(void)strerror_r(errno, errbuf, (int)sizeof(errbuf));
+	pps_thread->log_hook(pps_thread, THREAD_ERROR,
+		"PPS: pthread_mutex_unlock() : %s\n", errbuf);
     }
     /*@ +unrecog @*/
 }
 
-int pps_thread_lastpps(struct gps_device_t *session, struct timedelta_t *td)
+int pps_thread_ppsout(volatile struct pps_thread_t *pps_thread,
+		       volatile struct timedelta_t *td)
 /* return the delta at the time of the last PPS - only way we pass data out */
 {
     volatile int ret;
@@ -825,19 +868,21 @@ int pps_thread_lastpps(struct gps_device_t *session, struct timedelta_t *td)
     /*@ -unrecog  (splint has no pthread declarations as yet) @*/
     pthread_err = pthread_mutex_lock(&ppslast_mutex);
     if ( 0 != pthread_err ) {
-	gpsd_report(&session->context->errout, LOG_ERROR,
-		"PPS: pthread_mutex_lock() : %s\n",
-		strerror(errno));
+	char errbuf[BUFSIZ] = "unknown error";
+	(void)strerror_r(errno, errbuf,(int) sizeof(errbuf));
+	pps_thread->log_hook(pps_thread, THREAD_ERROR,
+		"PPS: pthread_mutex_lock() : %s\n", errbuf);
     }
     /*@ +unrecog @*/
-    *td = session->ppslast;
-    ret = session->ppscount;
+    *td = pps_thread->ppsout_last;
+    ret = pps_thread->ppsout_count;
     /*@ -unrecog (splint has no pthread declarations as yet) @*/
     pthread_err = pthread_mutex_unlock(&ppslast_mutex);
     if ( 0 != pthread_err ) {
-	gpsd_report(&session->context->errout, LOG_ERROR,
-		"PPS: pthread_mutex_unlock() : %s\n",
-		strerror(errno));
+	char errbuf[BUFSIZ] = "unknown error";
+	(void)strerror_r(errno, errbuf, (int)sizeof(errbuf));
+	pps_thread->log_hook(pps_thread, THREAD_ERROR,
+		"PPS: pthread_mutex_unlock() : %s\n", errbuf);
     }
     /*@ +unrecog @*/
 
