@@ -18,12 +18,12 @@
 #include <sys/param.h>	/* defines BSD */
 
 #include "gpsd_config.h"
-#ifdef HAVE_BLUEZ
+#ifdef ENABLE_BLUEZ
 #include <bluetooth/bluetooth.h>
 #include <bluetooth/hci.h>
 #include <bluetooth/hci_lib.h>
 #include <bluetooth/rfcomm.h>
-#endif /* HAVE_BLUEZ */
+#endif /* ENABLE_BLUEZ */
 
 #include "gpsd.h"
 
@@ -241,8 +241,8 @@ bool gpsd_set_raw(struct gps_device_t * session)
 {
     (void)cfmakeraw(&session->ttyset);
     if (tcsetattr(session->gpsdata.gps_fd, TCIOFLUSH, &session->ttyset) == -1) {
-	gpsd_report(&session->context->errout, LOG_ERROR,
-		    "error changing port attributes: %s\n", strerror(errno));
+	gpsd_log(&session->context->errout, LOG_ERROR,
+		 "error changing port attributes: %s\n", strerror(errno));
 	return false;
     }
 
@@ -374,10 +374,10 @@ void gpsd_set_speed(struct gps_device_t *session,
 	(void)usleep(200000);
 	(void)tcflush(session->gpsdata.gps_fd, TCIOFLUSH);
     }
-    gpsd_report(&session->context->errout, LOG_INF,
-		"speed %u, %d%c%d\n",
-		gpsd_get_speed(session), 9 - stopbits, parity,
-		stopbits);
+    gpsd_log(&session->context->errout, LOG_INF,
+	     "speed %lu, %d%c%d\n",
+	     (unsigned long)gpsd_get_speed(session), 9 - stopbits, parity,
+	     stopbits);
 
     session->gpsdata.dev.baudrate = (unsigned int)speed;
     session->gpsdata.dev.parity = parity;
@@ -420,16 +420,16 @@ int gpsd_serial_open(struct gps_device_t *session)
     if (session->context->readonly
 	|| (session->sourcetype <= source_blockdev)) {
 	mode = (mode_t) O_RDONLY;
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "opening read-only GPS data source type %d and at '%s'\n",
-		    (int)session->sourcetype, session->gpsdata.dev.path);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "opening read-only GPS data source type %d and at '%s'\n",
+		 (int)session->sourcetype, session->gpsdata.dev.path);
     } else {
-	gpsd_report(&session->context->errout, LOG_INF,
-		    "opening GPS data source type %d at '%s'\n",
-		    (int)session->sourcetype, session->gpsdata.dev.path);
+	gpsd_log(&session->context->errout, LOG_INF,
+		 "opening GPS data source type %d at '%s'\n",
+		 (int)session->sourcetype, session->gpsdata.dev.path);
     }
     /*@ +boolops +type @*/
-#ifdef HAVE_BLUEZ
+#ifdef ENABLE_BLUEZ
     if (bachk(session->gpsdata.dev.path) == 0) {
         struct sockaddr_rc addr = { 0, *BDADDR_ANY, 0};
         session->gpsdata.gps_fd = socket(AF_BLUETOOTH,
@@ -441,19 +441,19 @@ int gpsd_serial_open(struct gps_device_t *session)
         if (connect(session->gpsdata.gps_fd, (struct sockaddr *) &addr, sizeof (addr)) == -1) {
 	    if (errno != EINPROGRESS && errno != EAGAIN) {
 		(void)close(session->gpsdata.gps_fd);
-		gpsd_report(&session->context->errout, LOG_ERROR,
-			    "bluetooth socket connect failed: %s\n",
-			    strerror(errno));
+		gpsd_log(&session->context->errout, LOG_ERROR,
+			 "bluetooth socket connect failed: %s\n",
+			 strerror(errno));
 		return -1;
 	    }
-	    gpsd_report(&session->context->errout, LOG_ERROR,
-			"bluetooth socket connect in progress or again : %s\n",
-			strerror(errno));
+	    gpsd_log(&session->context->errout, LOG_ERROR,
+		     "bluetooth socket connect in progress or again : %s\n",
+		     strerror(errno));
         }
 	(void)fcntl(session->gpsdata.gps_fd, F_SETFL, (int)mode);
-	gpsd_report(&session->context->errout, LOG_PROG,
-		    "bluez device open success: %s %s\n",
-		    session->gpsdata.dev.path, strerror(errno));
+	gpsd_log(&session->context->errout, LOG_PROG,
+		 "bluez device open success: %s %s\n",
+		 session->gpsdata.dev.path, strerror(errno));
     } else
 #endif /* BLUEZ */
     {
@@ -463,20 +463,23 @@ int gpsd_serial_open(struct gps_device_t *session)
 	 */
         if ((session->gpsdata.gps_fd =
 	     open(session->gpsdata.dev.path, (int)(mode | O_NONBLOCK | O_NOCTTY))) == -1) {
-            gpsd_report(&session->context->errout, LOG_ERROR,
-			    "device open failed: %s - retrying read-only\n",
-			    strerror(errno));
+            gpsd_log(&session->context->errout, LOG_ERROR,
+		     "device open of %s failed: %s - retrying read-only\n",
+		     session->gpsdata.dev.path,
+		     strerror(errno));
 	    if ((session->gpsdata.gps_fd =
 		 open(session->gpsdata.dev.path, O_RDONLY | O_NONBLOCK | O_NOCTTY)) == -1) {
-		gpsd_report(&session->context->errout, LOG_ERROR,
-			    "read-only device open failed: %s\n",
-			    strerror(errno));
+		gpsd_log(&session->context->errout, LOG_ERROR,
+			 "read-only device open of %s failed: %s\n",
+			 session->gpsdata.dev.path,
+			 strerror(errno));
 		return -1;
 	    }
 
-	    gpsd_report(&session->context->errout, LOG_PROG,
-			"file device open success: %s\n",
-			strerror(errno));
+	    gpsd_log(&session->context->errout, LOG_PROG,
+		     "file device open of %s succeeded: %s\n",
+		     session->gpsdata.dev.path,
+		     strerror(errno));
 	}
     }
 
@@ -506,9 +509,9 @@ int gpsd_serial_open(struct gps_device_t *session)
 	 * Don't touch devices already opened by another process.
 	 */
 	if (fusercount(session->gpsdata.dev.path) > 1) {
-            gpsd_report(&session->context->errout, LOG_ERROR,
-			"%s already opened by another process\n",
-			session->gpsdata.dev.path);
+            gpsd_log(&session->context->errout, LOG_ERROR,
+		     "%s already opened by another process\n",
+		     session->gpsdata.dev.path);
 	    (void)close(session->gpsdata.gps_fd);
 	    session->gpsdata.gps_fd = -1;
 	    return -1;
@@ -588,9 +591,9 @@ int gpsd_serial_open(struct gps_device_t *session)
 	session->gpsdata.dev.stopbits = 1;
     }
 
-    gpsd_report(&session->context->errout, LOG_SPIN,
-		"open(%s) -> %d in gpsd_serial_open()\n",
-		session->gpsdata.dev.path, session->gpsdata.gps_fd);
+    gpsd_log(&session->context->errout, LOG_SPIN,
+	     "open(%s) -> %d in gpsd_serial_open()\n",
+	     session->gpsdata.dev.path, session->gpsdata.gps_fd);
     return session->gpsdata.gps_fd;
 }
 
@@ -608,10 +611,10 @@ ssize_t gpsd_serial_write(struct gps_device_t * session,
     /* extra guard prevents expensive hexdump calls */
     if (session->context->errout.debug >= LOG_IO) {
 	char scratchbuf[MAX_PACKET_LENGTH*2+1];
-	gpsd_report(&session->context->errout, LOG_IO,
-		    "=> GPS: %s%s\n",
-		    gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
-				    (char *)buf, len), ok ? "" : " FAILED");
+	gpsd_log(&session->context->errout, LOG_IO,
+		 "=> GPS: %s%s\n",
+		 gpsd_packetdump(scratchbuf, sizeof(scratchbuf),
+				 (char *)buf, len), ok ? "" : " FAILED");
     }
     return status;
 }
@@ -721,9 +724,9 @@ void gpsd_close(struct gps_device_t *session)
 	    (void)tcsetattr(session->gpsdata.gps_fd, TCSANOW,
 			    &session->ttyset_old);
 	}
-	gpsd_report(&session->context->errout, LOG_SPIN,
-		    "close(%d) in gpsd_close(%s)\n",
-		    session->gpsdata.gps_fd, session->gpsdata.dev.path);
+	gpsd_log(&session->context->errout, LOG_SPIN,
+		 "close(%d) in gpsd_close(%s)\n",
+		 session->gpsdata.gps_fd, session->gpsdata.dev.path);
 	(void)close(session->gpsdata.gps_fd);
 	session->gpsdata.gps_fd = -1;
     }
